/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * This file was generated.
 *  with google-apis-code-generator 1.4.0 (build: 2013-06-20 19:08:55 UTC)
 *  on 2013-06-25 at 22:02:28 UTC 
 */

package com.google.api.services.bigquery;

import com.google.api.client.googleapis.GoogleUtils;
import com.google.api.client.googleapis.services.AbstractGoogleClientRequest;
import com.google.api.client.googleapis.services.GoogleClientRequestInitializer;
import com.google.api.client.googleapis.services.json.AbstractGoogleJsonClient;
import com.google.api.client.http.HttpRequestInitializer;
import com.google.api.client.http.HttpTransport;
import com.google.api.client.json.JsonFactory;
import com.google.api.client.json.JsonObjectParser;
import com.google.api.client.json.JsonString;
import com.google.common.base.Preconditions;
import com.google.common.primitives.UnsignedLong;

/**
 * Service definition for Bigquery (v2).
 *
 * <p>
 * A data platform for customers to create, manage, share and query data.
 * </p>
 *
 * <p>
 * For more information about this service, see the
 * <a href="https://developers.google.com/bigquery/docs/overview" target="_blank">API Documentation</a>
 * </p>
 *
 * <p>
 * This service uses {@link BigqueryRequestInitializer} to initialize global parameters via its
 * {@link Builder}.
 * </p>
 *
 * <p>
 * Upgrade warning: this class now extends {@link AbstractGoogleJsonClient}, whereas in prior
 * version 1.8 it extended {@link com.google.api.client.googleapis.services.GoogleClient}.
 * </p>
 *
 * @since 1.3
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public class Bigquery extends AbstractGoogleJsonClient {

  // Note: Leave this static initializer at the top of the file.
  static {
    Preconditions.checkState(GoogleUtils.VERSION.equals("1.13.2-beta"),
        "You are currently running with version %s of google-api-client. " +
        "You need version 1.13.2-beta of google-api-client to run version " +
        "1.13.2-beta of the BigQuery API library.", GoogleUtils.VERSION);
  }

  /**
   * The default encoded root URL of the service. This is determined when the library is generated
   * and normally should not be changed.
   *
   * @since 1.7
   */
  public static final String DEFAULT_ROOT_URL = "https://www.googleapis.com/";

  /**
   * The default encoded service path of the service. This is determined when the library is
   * generated and normally should not be changed.
   *
   * @since 1.7
   */
  public static final String DEFAULT_SERVICE_PATH = "bigquery/v2/";

  /**
   * The default encoded base URL of the service. This is determined when the library is generated
   * and normally should not be changed.
   * @deprecated (scheduled to be removed in 1.13)
   */
  @Deprecated
  public static final String DEFAULT_BASE_URL = DEFAULT_ROOT_URL + DEFAULT_SERVICE_PATH;

  /**
   * Constructor.
   *
   * <p>
   * Use {@link Builder} if you need to specify any of the optional parameters.
   * </p>
   *
   * @param transport HTTP transport
   * @param jsonFactory JSON factory
   * @param httpRequestInitializer HTTP request initializer or {@code null} for none
   * @since 1.7
   */
  public Bigquery(HttpTransport transport, JsonFactory jsonFactory,
      HttpRequestInitializer httpRequestInitializer) {
    super(transport,
        jsonFactory,
        DEFAULT_ROOT_URL,
        DEFAULT_SERVICE_PATH,
        httpRequestInitializer,
        false);
  }

  /**
   * @param transport HTTP transport
   * @param httpRequestInitializer HTTP request initializer or {@code null} for none
   * @param rootUrl root URL of the service
   * @param servicePath service path
   * @param jsonObjectParser JSON object parser
   * @param googleClientRequestInitializer Google request initializer or {@code null} for none
   * @param applicationName application name to be sent in the User-Agent header of requests or
   *        {@code null} for none
   * @param suppressPatternChecks whether discovery pattern checks should be suppressed on required
   *        parameters
   */
  Bigquery(HttpTransport transport,
      HttpRequestInitializer httpRequestInitializer,
      String rootUrl,
      String servicePath,
      JsonObjectParser jsonObjectParser,
      GoogleClientRequestInitializer googleClientRequestInitializer,
      String applicationName,
      boolean suppressPatternChecks) {
    super(transport,
        httpRequestInitializer,
        rootUrl,
        servicePath,
        jsonObjectParser,
        googleClientRequestInitializer,
        applicationName,
        suppressPatternChecks);
  }

  @Override
  protected void initialize(AbstractGoogleClientRequest<?> httpClientRequest) throws java.io.IOException {
    super.initialize(httpClientRequest);
  }

  /**
   * An accessor for creating requests from the Datasets collection.
   *
   * <p>The typical use is:</p>
   * <pre>
   *   {@code Bigquery bigquery = new Bigquery(...);}
   *   {@code Bigquery.Datasets.List request = bigquery.datasets().list(parameters ...)}
   * </pre>
   *
   * @return the resource collection
   */
  public Datasets datasets() {
    return new Datasets();
  }

  /**
   * The "datasets" collection of methods.
   */
  public class Datasets {

    /**
     * Deletes the dataset specified by datasetId value. Before you can delete a dataset, you must
     * delete all its tables, either manually or by specifying deleteContents. Immediately after
     * deletion, you can create another dataset with the same name.
     *
     * Create a request for the method "datasets.delete".
     *
     * This request holds the parameters needed by the the bigquery server.  After setting any optional
     * parameters, call the {@link Delete#execute()} method to invoke the remote operation.
     *
     * @param projectId Project ID of the dataset being deleted
     * @param datasetId Dataset ID of dataset being deleted
     * @return the request
     */
    public Delete delete(String projectId, String datasetId) throws java.io.IOException {
      Delete result = new Delete(projectId, datasetId);
      initialize(result);
      return result;
    }

    public class Delete extends BigqueryRequest<Void> {

      private static final String REST_PATH = "projects/{projectId}/datasets/{datasetId}";

      /**
       * Deletes the dataset specified by datasetId value. Before you can delete a dataset, you must
       * delete all its tables, either manually or by specifying deleteContents. Immediately after
       * deletion, you can create another dataset with the same name.
       *
       * Create a request for the method "datasets.delete".
       *
       * This request holds the parameters needed by the the bigquery server.  After setting any
       * optional parameters, call the {@link Delete#execute()} method to invoke the remote operation.
       * <p> {@link Delete#initialize(AbstractGoogleClientRequest)} must be called to initialize this
       * instance immediately after invoking the constructor. </p>
       *
       * @param projectId Project ID of the dataset being deleted
       * @param datasetId Dataset ID of dataset being deleted
       * @since 1.13
       */
      protected Delete(String projectId, String datasetId) {
        super(Bigquery.this, "DELETE", REST_PATH, null, Void.class);
        this.projectId = Preconditions.checkNotNull(projectId, "Required parameter projectId must be specified.");
        this.datasetId = Preconditions.checkNotNull(datasetId, "Required parameter datasetId must be specified.");
      }

      @Override
      public Delete setAlt(String alt) {
        return (Delete) super.setAlt(alt);
      }

      @Override
      public Delete setFields(String fields) {
        return (Delete) super.setFields(fields);
      }

      @Override
      public Delete setKey(String key) {
        return (Delete) super.setKey(key);
      }

      @Override
      public Delete setOauthToken(String oauthToken) {
        return (Delete) super.setOauthToken(oauthToken);
      }

      @Override
      public Delete setPrettyPrint(Boolean prettyPrint) {
        return (Delete) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public Delete setQuotaUser(String quotaUser) {
        return (Delete) super.setQuotaUser(quotaUser);
      }

      @Override
      public Delete setUserIp(String userIp) {
        return (Delete) super.setUserIp(userIp);
      }

      /** Project ID of the dataset being deleted */
      @com.google.api.client.util.Key
      private String projectId;

      /** Project ID of the dataset being deleted
       */
      public String getProjectId() {
        return projectId;
      }

      /** Project ID of the dataset being deleted */
      public Delete setProjectId(String projectId) {
        this.projectId = projectId;
        return this;
      }

      /** Dataset ID of dataset being deleted */
      @com.google.api.client.util.Key
      private String datasetId;

      /** Dataset ID of dataset being deleted
       */
      public String getDatasetId() {
        return datasetId;
      }

      /** Dataset ID of dataset being deleted */
      public Delete setDatasetId(String datasetId) {
        this.datasetId = datasetId;
        return this;
      }

      /**
     * If True, delete all the tables in the dataset. If False and the dataset contains tables, the
     * request will fail. Default is False
     */
      @com.google.api.client.util.Key
      private Boolean deleteContents;

      /** If True, delete all the tables in the dataset. If False and the dataset contains tables, the
     request will fail. Default is False
       */
      public Boolean getDeleteContents() {
        return deleteContents;
      }

      /**
     * If True, delete all the tables in the dataset. If False and the dataset contains tables, the
     * request will fail. Default is False
     */
      public Delete setDeleteContents(Boolean deleteContents) {
        this.deleteContents = deleteContents;
        return this;
      }

    }
    /**
     * Returns the dataset specified by datasetID.
     *
     * Create a request for the method "datasets.get".
     *
     * This request holds the parameters needed by the the bigquery server.  After setting any optional
     * parameters, call the {@link Get#execute()} method to invoke the remote operation.
     *
     * @param projectId Project ID of the requested dataset
     * @param datasetId Dataset ID of the requested dataset
     * @return the request
     */
    public Get get(String projectId, String datasetId) throws java.io.IOException {
      Get result = new Get(projectId, datasetId);
      initialize(result);
      return result;
    }

    public class Get extends BigqueryRequest<com.google.api.services.bigquery.model.Dataset> {

      private static final String REST_PATH = "projects/{projectId}/datasets/{datasetId}";

      /**
       * Returns the dataset specified by datasetID.
       *
       * Create a request for the method "datasets.get".
       *
       * This request holds the parameters needed by the the bigquery server.  After setting any
       * optional parameters, call the {@link Get#execute()} method to invoke the remote operation. <p>
       * {@link Get#initialize(AbstractGoogleClientRequest)} must be called to initialize this instance
       * immediately after invoking the constructor. </p>
       *
       * @param projectId Project ID of the requested dataset
       * @param datasetId Dataset ID of the requested dataset
       * @since 1.13
       */
      protected Get(String projectId, String datasetId) {
        super(Bigquery.this, "GET", REST_PATH, null, com.google.api.services.bigquery.model.Dataset.class);
        this.projectId = Preconditions.checkNotNull(projectId, "Required parameter projectId must be specified.");
        this.datasetId = Preconditions.checkNotNull(datasetId, "Required parameter datasetId must be specified.");
      }

      @Override
      public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
        return super.executeUsingHead();
      }

      @Override
      public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
        return super.buildHttpRequestUsingHead();
      }

      @Override
      public Get setAlt(String alt) {
        return (Get) super.setAlt(alt);
      }

      @Override
      public Get setFields(String fields) {
        return (Get) super.setFields(fields);
      }

      @Override
      public Get setKey(String key) {
        return (Get) super.setKey(key);
      }

      @Override
      public Get setOauthToken(String oauthToken) {
        return (Get) super.setOauthToken(oauthToken);
      }

      @Override
      public Get setPrettyPrint(Boolean prettyPrint) {
        return (Get) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public Get setQuotaUser(String quotaUser) {
        return (Get) super.setQuotaUser(quotaUser);
      }

      @Override
      public Get setUserIp(String userIp) {
        return (Get) super.setUserIp(userIp);
      }

      /** Project ID of the requested dataset */
      @com.google.api.client.util.Key
      private String projectId;

      /** Project ID of the requested dataset
       */
      public String getProjectId() {
        return projectId;
      }

      /** Project ID of the requested dataset */
      public Get setProjectId(String projectId) {
        this.projectId = projectId;
        return this;
      }

      /** Dataset ID of the requested dataset */
      @com.google.api.client.util.Key
      private String datasetId;

      /** Dataset ID of the requested dataset
       */
      public String getDatasetId() {
        return datasetId;
      }

      /** Dataset ID of the requested dataset */
      public Get setDatasetId(String datasetId) {
        this.datasetId = datasetId;
        return this;
      }

    }
    /**
     * Creates a new empty dataset.
     *
     * Create a request for the method "datasets.insert".
     *
     * This request holds the parameters needed by the the bigquery server.  After setting any optional
     * parameters, call the {@link Insert#execute()} method to invoke the remote operation.
     *
     * @param projectId Project ID of the new dataset
     * @param content the {@link com.google.api.services.bigquery.model.Dataset}
     * @return the request
     */
    public Insert insert(String projectId, com.google.api.services.bigquery.model.Dataset content) throws java.io.IOException {
      Insert result = new Insert(projectId, content);
      initialize(result);
      return result;
    }

    public class Insert extends BigqueryRequest<com.google.api.services.bigquery.model.Dataset> {

      private static final String REST_PATH = "projects/{projectId}/datasets";

      /**
       * Creates a new empty dataset.
       *
       * Create a request for the method "datasets.insert".
       *
       * This request holds the parameters needed by the the bigquery server.  After setting any
       * optional parameters, call the {@link Insert#execute()} method to invoke the remote operation.
       * <p> {@link Insert#initialize(AbstractGoogleClientRequest)} must be called to initialize this
       * instance immediately after invoking the constructor. </p>
       *
       * @param projectId Project ID of the new dataset
       * @param content the {@link com.google.api.services.bigquery.model.Dataset}
       * @since 1.13
       */
      protected Insert(String projectId, com.google.api.services.bigquery.model.Dataset content) {
        super(Bigquery.this, "POST", REST_PATH, content, com.google.api.services.bigquery.model.Dataset.class);
        this.projectId = Preconditions.checkNotNull(projectId, "Required parameter projectId must be specified.");
      }

      @Override
      public Insert setAlt(String alt) {
        return (Insert) super.setAlt(alt);
      }

      @Override
      public Insert setFields(String fields) {
        return (Insert) super.setFields(fields);
      }

      @Override
      public Insert setKey(String key) {
        return (Insert) super.setKey(key);
      }

      @Override
      public Insert setOauthToken(String oauthToken) {
        return (Insert) super.setOauthToken(oauthToken);
      }

      @Override
      public Insert setPrettyPrint(Boolean prettyPrint) {
        return (Insert) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public Insert setQuotaUser(String quotaUser) {
        return (Insert) super.setQuotaUser(quotaUser);
      }

      @Override
      public Insert setUserIp(String userIp) {
        return (Insert) super.setUserIp(userIp);
      }

      /** Project ID of the new dataset */
      @com.google.api.client.util.Key
      private String projectId;

      /** Project ID of the new dataset
       */
      public String getProjectId() {
        return projectId;
      }

      /** Project ID of the new dataset */
      public Insert setProjectId(String projectId) {
        this.projectId = projectId;
        return this;
      }

    }
    /**
     * Lists all the datasets in the specified project to which the caller has read access; however, a
     * project owner can list (but not necessarily get) all datasets in his project.
     *
     * Create a request for the method "datasets.list".
     *
     * This request holds the parameters needed by the the bigquery server.  After setting any optional
     * parameters, call the {@link List#execute()} method to invoke the remote operation.
     *
     * @param projectId Project ID of the datasets to be listed
     * @return the request
     */
    public List list(String projectId) throws java.io.IOException {
      List result = new List(projectId);
      initialize(result);
      return result;
    }

    public class List extends BigqueryRequest<com.google.api.services.bigquery.model.DatasetList> {

      private static final String REST_PATH = "projects/{projectId}/datasets";

      /**
       * Lists all the datasets in the specified project to which the caller has read access; however, a
       * project owner can list (but not necessarily get) all datasets in his project.
       *
       * Create a request for the method "datasets.list".
       *
       * This request holds the parameters needed by the the bigquery server.  After setting any
       * optional parameters, call the {@link List#execute()} method to invoke the remote operation. <p>
       * {@link List#initialize(AbstractGoogleClientRequest)} must be called to initialize this instance
       * immediately after invoking the constructor. </p>
       *
       * @param projectId Project ID of the datasets to be listed
       * @since 1.13
       */
      protected List(String projectId) {
        super(Bigquery.this, "GET", REST_PATH, null, com.google.api.services.bigquery.model.DatasetList.class);
        this.projectId = Preconditions.checkNotNull(projectId, "Required parameter projectId must be specified.");
      }

      @Override
      public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
        return super.executeUsingHead();
      }

      @Override
      public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
        return super.buildHttpRequestUsingHead();
      }

      @Override
      public List setAlt(String alt) {
        return (List) super.setAlt(alt);
      }

      @Override
      public List setFields(String fields) {
        return (List) super.setFields(fields);
      }

      @Override
      public List setKey(String key) {
        return (List) super.setKey(key);
      }

      @Override
      public List setOauthToken(String oauthToken) {
        return (List) super.setOauthToken(oauthToken);
      }

      @Override
      public List setPrettyPrint(Boolean prettyPrint) {
        return (List) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public List setQuotaUser(String quotaUser) {
        return (List) super.setQuotaUser(quotaUser);
      }

      @Override
      public List setUserIp(String userIp) {
        return (List) super.setUserIp(userIp);
      }

      /** Project ID of the datasets to be listed */
      @com.google.api.client.util.Key
      private String projectId;

      /** Project ID of the datasets to be listed
       */
      public String getProjectId() {
        return projectId;
      }

      /** Project ID of the datasets to be listed */
      public List setProjectId(String projectId) {
        this.projectId = projectId;
        return this;
      }

      /** Page token, returned by a previous call, to request the next page of results */
      @com.google.api.client.util.Key
      private String pageToken;

      /** Page token, returned by a previous call, to request the next page of results
       */
      public String getPageToken() {
        return pageToken;
      }

      /** Page token, returned by a previous call, to request the next page of results */
      public List setPageToken(String pageToken) {
        this.pageToken = pageToken;
        return this;
      }

      /** The maximum number of results to return */
      @com.google.api.client.util.Key
      private Long maxResults;

      /** The maximum number of results to return
       */
      public Long getMaxResults() {
        return maxResults;
      }

      /** The maximum number of results to return */
      public List setMaxResults(Long maxResults) {
        this.maxResults = maxResults;
        return this;
      }

    }
    /**
     * Updates information in an existing dataset, specified by datasetId. Properties not included in
     * the submitted resource will not be changed. If you include the access property without any values
     * assigned, the request will fail as you must specify at least one owner for a dataset. This method
     * supports patch semantics.
     *
     * Create a request for the method "datasets.patch".
     *
     * This request holds the parameters needed by the the bigquery server.  After setting any optional
     * parameters, call the {@link Patch#execute()} method to invoke the remote operation.
     *
     * @param projectId Project ID of the dataset being updated
     * @param datasetId Dataset ID of the dataset being updated
     * @param content the {@link com.google.api.services.bigquery.model.Dataset}
     * @return the request
     */
    public Patch patch(String projectId, String datasetId, com.google.api.services.bigquery.model.Dataset content) throws java.io.IOException {
      Patch result = new Patch(projectId, datasetId, content);
      initialize(result);
      return result;
    }

    public class Patch extends BigqueryRequest<com.google.api.services.bigquery.model.Dataset> {

      private static final String REST_PATH = "projects/{projectId}/datasets/{datasetId}";

      /**
       * Updates information in an existing dataset, specified by datasetId. Properties not included in
       * the submitted resource will not be changed. If you include the access property without any
       * values assigned, the request will fail as you must specify at least one owner for a dataset.
       * This method supports patch semantics.
       *
       * Create a request for the method "datasets.patch".
       *
       * This request holds the parameters needed by the the bigquery server.  After setting any
       * optional parameters, call the {@link Patch#execute()} method to invoke the remote operation.
       * <p> {@link Patch#initialize(AbstractGoogleClientRequest)} must be called to initialize this
       * instance immediately after invoking the constructor. </p>
       *
       * @param projectId Project ID of the dataset being updated
       * @param datasetId Dataset ID of the dataset being updated
       * @param content the {@link com.google.api.services.bigquery.model.Dataset}
       * @since 1.13
       */
      protected Patch(String projectId, String datasetId, com.google.api.services.bigquery.model.Dataset content) {
        super(Bigquery.this, "PATCH", REST_PATH, content, com.google.api.services.bigquery.model.Dataset.class);
        this.projectId = Preconditions.checkNotNull(projectId, "Required parameter projectId must be specified.");
        this.datasetId = Preconditions.checkNotNull(datasetId, "Required parameter datasetId must be specified.");
      }

      @Override
      public Patch setAlt(String alt) {
        return (Patch) super.setAlt(alt);
      }

      @Override
      public Patch setFields(String fields) {
        return (Patch) super.setFields(fields);
      }

      @Override
      public Patch setKey(String key) {
        return (Patch) super.setKey(key);
      }

      @Override
      public Patch setOauthToken(String oauthToken) {
        return (Patch) super.setOauthToken(oauthToken);
      }

      @Override
      public Patch setPrettyPrint(Boolean prettyPrint) {
        return (Patch) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public Patch setQuotaUser(String quotaUser) {
        return (Patch) super.setQuotaUser(quotaUser);
      }

      @Override
      public Patch setUserIp(String userIp) {
        return (Patch) super.setUserIp(userIp);
      }

      /** Project ID of the dataset being updated */
      @com.google.api.client.util.Key
      private String projectId;

      /** Project ID of the dataset being updated
       */
      public String getProjectId() {
        return projectId;
      }

      /** Project ID of the dataset being updated */
      public Patch setProjectId(String projectId) {
        this.projectId = projectId;
        return this;
      }

      /** Dataset ID of the dataset being updated */
      @com.google.api.client.util.Key
      private String datasetId;

      /** Dataset ID of the dataset being updated
       */
      public String getDatasetId() {
        return datasetId;
      }

      /** Dataset ID of the dataset being updated */
      public Patch setDatasetId(String datasetId) {
        this.datasetId = datasetId;
        return this;
      }

    }
    /**
     * Updates information in an existing dataset, specified by datasetId. Properties not included in
     * the submitted resource will not be changed. If you include the access property without any values
     * assigned, the request will fail as you must specify at least one owner for a dataset.
     *
     * Create a request for the method "datasets.update".
     *
     * This request holds the parameters needed by the the bigquery server.  After setting any optional
     * parameters, call the {@link Update#execute()} method to invoke the remote operation.
     *
     * @param projectId Project ID of the dataset being updated
     * @param datasetId Dataset ID of the dataset being updated
     * @param content the {@link com.google.api.services.bigquery.model.Dataset}
     * @return the request
     */
    public Update update(String projectId, String datasetId, com.google.api.services.bigquery.model.Dataset content) throws java.io.IOException {
      Update result = new Update(projectId, datasetId, content);
      initialize(result);
      return result;
    }

    public class Update extends BigqueryRequest<com.google.api.services.bigquery.model.Dataset> {

      private static final String REST_PATH = "projects/{projectId}/datasets/{datasetId}";

      /**
       * Updates information in an existing dataset, specified by datasetId. Properties not included in
       * the submitted resource will not be changed. If you include the access property without any
       * values assigned, the request will fail as you must specify at least one owner for a dataset.
       *
       * Create a request for the method "datasets.update".
       *
       * This request holds the parameters needed by the the bigquery server.  After setting any
       * optional parameters, call the {@link Update#execute()} method to invoke the remote operation.
       * <p> {@link Update#initialize(AbstractGoogleClientRequest)} must be called to initialize this
       * instance immediately after invoking the constructor. </p>
       *
       * @param projectId Project ID of the dataset being updated
       * @param datasetId Dataset ID of the dataset being updated
       * @param content the {@link com.google.api.services.bigquery.model.Dataset}
       * @since 1.13
       */
      protected Update(String projectId, String datasetId, com.google.api.services.bigquery.model.Dataset content) {
        super(Bigquery.this, "PUT", REST_PATH, content, com.google.api.services.bigquery.model.Dataset.class);
        this.projectId = Preconditions.checkNotNull(projectId, "Required parameter projectId must be specified.");
        this.datasetId = Preconditions.checkNotNull(datasetId, "Required parameter datasetId must be specified.");
      }

      @Override
      public Update setAlt(String alt) {
        return (Update) super.setAlt(alt);
      }

      @Override
      public Update setFields(String fields) {
        return (Update) super.setFields(fields);
      }

      @Override
      public Update setKey(String key) {
        return (Update) super.setKey(key);
      }

      @Override
      public Update setOauthToken(String oauthToken) {
        return (Update) super.setOauthToken(oauthToken);
      }

      @Override
      public Update setPrettyPrint(Boolean prettyPrint) {
        return (Update) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public Update setQuotaUser(String quotaUser) {
        return (Update) super.setQuotaUser(quotaUser);
      }

      @Override
      public Update setUserIp(String userIp) {
        return (Update) super.setUserIp(userIp);
      }

      /** Project ID of the dataset being updated */
      @com.google.api.client.util.Key
      private String projectId;

      /** Project ID of the dataset being updated
       */
      public String getProjectId() {
        return projectId;
      }

      /** Project ID of the dataset being updated */
      public Update setProjectId(String projectId) {
        this.projectId = projectId;
        return this;
      }

      /** Dataset ID of the dataset being updated */
      @com.google.api.client.util.Key
      private String datasetId;

      /** Dataset ID of the dataset being updated
       */
      public String getDatasetId() {
        return datasetId;
      }

      /** Dataset ID of the dataset being updated */
      public Update setDatasetId(String datasetId) {
        this.datasetId = datasetId;
        return this;
      }

    }

  }

  /**
   * An accessor for creating requests from the Jobs collection.
   *
   * <p>The typical use is:</p>
   * <pre>
   *   {@code Bigquery bigquery = new Bigquery(...);}
   *   {@code Bigquery.Jobs.List request = bigquery.jobs().list(parameters ...)}
   * </pre>
   *
   * @return the resource collection
   */
  public Jobs jobs() {
    return new Jobs();
  }

  /**
   * The "jobs" collection of methods.
   */
  public class Jobs {

    /**
     * Retrieves the specified job by ID.
     *
     * Create a request for the method "jobs.get".
     *
     * This request holds the parameters needed by the the bigquery server.  After setting any optional
     * parameters, call the {@link Get#execute()} method to invoke the remote operation.
     *
     * @param projectId Project ID of the requested job
     * @param jobId Job ID of the requested job
     * @return the request
     */
    public Get get(String projectId, String jobId) throws java.io.IOException {
      Get result = new Get(projectId, jobId);
      initialize(result);
      return result;
    }

    public class Get extends BigqueryRequest<com.google.api.services.bigquery.model.Job> {

      private static final String REST_PATH = "projects/{projectId}/jobs/{jobId}";

      /**
       * Retrieves the specified job by ID.
       *
       * Create a request for the method "jobs.get".
       *
       * This request holds the parameters needed by the the bigquery server.  After setting any
       * optional parameters, call the {@link Get#execute()} method to invoke the remote operation. <p>
       * {@link Get#initialize(AbstractGoogleClientRequest)} must be called to initialize this instance
       * immediately after invoking the constructor. </p>
       *
       * @param projectId Project ID of the requested job
       * @param jobId Job ID of the requested job
       * @since 1.13
       */
      protected Get(String projectId, String jobId) {
        super(Bigquery.this, "GET", REST_PATH, null, com.google.api.services.bigquery.model.Job.class);
        this.projectId = Preconditions.checkNotNull(projectId, "Required parameter projectId must be specified.");
        this.jobId = Preconditions.checkNotNull(jobId, "Required parameter jobId must be specified.");
      initializeMediaDownload();
      }

      /** Upgrade warning: in prior version 1.8 this method was called {@code download}. */
      @Override
      public void executeMediaAndDownloadTo(java.io.OutputStream outputStream) throws java.io.IOException {
        super.executeMediaAndDownloadTo(outputStream);
      }

      @Override
      public java.io.InputStream executeMediaAsInputStream() throws java.io.IOException {
        return super.executeMediaAsInputStream();
      }

      @Override
      public com.google.api.client.http.HttpResponse executeMedia() throws java.io.IOException {
        return super.executeMedia();
      }

      @Override
      public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
        return super.executeUsingHead();
      }

      @Override
      public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
        return super.buildHttpRequestUsingHead();
      }

      @Override
      public Get setAlt(String alt) {
        return (Get) super.setAlt(alt);
      }

      @Override
      public Get setFields(String fields) {
        return (Get) super.setFields(fields);
      }

      @Override
      public Get setKey(String key) {
        return (Get) super.setKey(key);
      }

      @Override
      public Get setOauthToken(String oauthToken) {
        return (Get) super.setOauthToken(oauthToken);
      }

      @Override
      public Get setPrettyPrint(Boolean prettyPrint) {
        return (Get) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public Get setQuotaUser(String quotaUser) {
        return (Get) super.setQuotaUser(quotaUser);
      }

      @Override
      public Get setUserIp(String userIp) {
        return (Get) super.setUserIp(userIp);
      }

      /** Project ID of the requested job */
      @com.google.api.client.util.Key
      private String projectId;

      /** Project ID of the requested job
       */
      public String getProjectId() {
        return projectId;
      }

      /** Project ID of the requested job */
      public Get setProjectId(String projectId) {
        this.projectId = projectId;
        return this;
      }

      /** Job ID of the requested job */
      @com.google.api.client.util.Key
      private String jobId;

      /** Job ID of the requested job
       */
      public String getJobId() {
        return jobId;
      }

      /** Job ID of the requested job */
      public Get setJobId(String jobId) {
        this.jobId = jobId;
        return this;
      }

    }
    /**
     * Retrieves the results of a query job.
     *
     * Create a request for the method "jobs.getQueryResults".
     *
     * This request holds the parameters needed by the the bigquery server.  After setting any optional
     * parameters, call the {@link GetQueryResults#execute()} method to invoke the remote operation.
     *
     * @param projectId Project ID of the query job
     * @param jobId Job ID of the query job
     * @return the request
     */
    public GetQueryResults getQueryResults(String projectId, String jobId) throws java.io.IOException {
      GetQueryResults result = new GetQueryResults(projectId, jobId);
      initialize(result);
      return result;
    }

    public class GetQueryResults extends BigqueryRequest<com.google.api.services.bigquery.model.GetQueryResultsResponse> {

      private static final String REST_PATH = "projects/{projectId}/queries/{jobId}";

      /**
       * Retrieves the results of a query job.
       *
       * Create a request for the method "jobs.getQueryResults".
       *
       * This request holds the parameters needed by the the bigquery server.  After setting any
       * optional parameters, call the {@link GetQueryResults#execute()} method to invoke the remote
       * operation. <p> {@link GetQueryResults#initialize(AbstractGoogleClientRequest)} must be called
       * to initialize this instance immediately after invoking the constructor. </p>
       *
       * @param projectId Project ID of the query job
       * @param jobId Job ID of the query job
       * @since 1.13
       */
      protected GetQueryResults(String projectId, String jobId) {
        super(Bigquery.this, "GET", REST_PATH, null, com.google.api.services.bigquery.model.GetQueryResultsResponse.class);
        this.projectId = Preconditions.checkNotNull(projectId, "Required parameter projectId must be specified.");
        this.jobId = Preconditions.checkNotNull(jobId, "Required parameter jobId must be specified.");
      initializeMediaDownload();
      }

      /** Upgrade warning: in prior version 1.8 this method was called {@code download}. */
      @Override
      public void executeMediaAndDownloadTo(java.io.OutputStream outputStream) throws java.io.IOException {
        super.executeMediaAndDownloadTo(outputStream);
      }

      @Override
      public java.io.InputStream executeMediaAsInputStream() throws java.io.IOException {
        return super.executeMediaAsInputStream();
      }

      @Override
      public com.google.api.client.http.HttpResponse executeMedia() throws java.io.IOException {
        return super.executeMedia();
      }

      @Override
      public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
        return super.executeUsingHead();
      }

      @Override
      public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
        return super.buildHttpRequestUsingHead();
      }

      @Override
      public GetQueryResults setAlt(String alt) {
        return (GetQueryResults) super.setAlt(alt);
      }

      @Override
      public GetQueryResults setFields(String fields) {
        return (GetQueryResults) super.setFields(fields);
      }

      @Override
      public GetQueryResults setKey(String key) {
        return (GetQueryResults) super.setKey(key);
      }

      @Override
      public GetQueryResults setOauthToken(String oauthToken) {
        return (GetQueryResults) super.setOauthToken(oauthToken);
      }

      @Override
      public GetQueryResults setPrettyPrint(Boolean prettyPrint) {
        return (GetQueryResults) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public GetQueryResults setQuotaUser(String quotaUser) {
        return (GetQueryResults) super.setQuotaUser(quotaUser);
      }

      @Override
      public GetQueryResults setUserIp(String userIp) {
        return (GetQueryResults) super.setUserIp(userIp);
      }

      /** Project ID of the query job */
      @com.google.api.client.util.Key
      private String projectId;

      /** Project ID of the query job
       */
      public String getProjectId() {
        return projectId;
      }

      /** Project ID of the query job */
      public GetQueryResults setProjectId(String projectId) {
        this.projectId = projectId;
        return this;
      }

      /** Job ID of the query job */
      @com.google.api.client.util.Key
      private String jobId;

      /** Job ID of the query job
       */
      public String getJobId() {
        return jobId;
      }

      /** Job ID of the query job */
      public GetQueryResults setJobId(String jobId) {
        this.jobId = jobId;
        return this;
      }

      /**
     * How long to wait for the query to complete, in milliseconds, before returning. Default is to
     * return immediately. If the timeout passes before the job completes, the request will fail
     * with a TIMEOUT error
     */
      @com.google.api.client.util.Key
      private Long timeoutMs;

      /** How long to wait for the query to complete, in milliseconds, before returning. Default is to return
     immediately. If the timeout passes before the job completes, the request will fail with a TIMEOUT
     error
       */
      public Long getTimeoutMs() {
        return timeoutMs;
      }

      /**
     * How long to wait for the query to complete, in milliseconds, before returning. Default is to
     * return immediately. If the timeout passes before the job completes, the request will fail
     * with a TIMEOUT error
     */
      public GetQueryResults setTimeoutMs(Long timeoutMs) {
        this.timeoutMs = timeoutMs;
        return this;
      }

      /** Maximum number of results to read */
      @com.google.api.client.util.Key
      private Long maxResults;

      /** Maximum number of results to read
       */
      public Long getMaxResults() {
        return maxResults;
      }

      /** Maximum number of results to read */
      public GetQueryResults setMaxResults(Long maxResults) {
        this.maxResults = maxResults;
        return this;
      }

      /** Page token, returned by a previous call, to request the next page of results */
      @com.google.api.client.util.Key
      private String pageToken;

      /** Page token, returned by a previous call, to request the next page of results
       */
      public String getPageToken() {
        return pageToken;
      }

      /** Page token, returned by a previous call, to request the next page of results */
      public GetQueryResults setPageToken(String pageToken) {
        this.pageToken = pageToken;
        return this;
      }

      /** Zero-based index of the starting row */
      @com.google.api.client.util.Key
      private UnsignedLong startIndex;

      /** Zero-based index of the starting row
       */
      public UnsignedLong getStartIndex() {
        return startIndex;
      }

      /** Zero-based index of the starting row */
      public GetQueryResults setStartIndex(UnsignedLong startIndex) {
        this.startIndex = startIndex;
        return this;
      }

    }
    /**
     * Starts a new asynchronous job.
     *
     * Create a request for the method "jobs.insert".
     *
     * This request holds the parameters needed by the the bigquery server.  After setting any optional
     * parameters, call the {@link Insert#execute()} method to invoke the remote operation.
     *
     * @param projectId Project ID of the project that will be billed for the job
     * @param content the {@link com.google.api.services.bigquery.model.Job}
     * @return the request
     */
    public Insert insert(String projectId, com.google.api.services.bigquery.model.Job content) throws java.io.IOException {
      Insert result = new Insert(projectId, content);
      initialize(result);
      return result;
    }

    /**
     * Starts a new asynchronous job.
     *
     * Create a request for the method "jobs.insert".
     *
     * This request holds the parameters needed by the the bigquery server.  After setting any optional
     * parameters, call the {@link Insert#execute()} method to invoke the remote operation.
     *
     * <p>
     * This method should be used for uploading media content.
     * </p>
     *
     * @param projectId Project ID of the project that will be billed for the job
     * @param content the {@link com.google.api.services.bigquery.model.Job} media metadata or {@code null} if none
     * @param mediaContent The media HTTP content or {@code null} if none.
     * @return the request
     * @throws java.io.IOException if the initialization of the request fails
     */
    public Insert insert(String projectId, com.google.api.services.bigquery.model.Job content,
        com.google.api.client.http.AbstractInputStreamContent mediaContent) throws java.io.IOException {
      Insert result = new Insert(projectId, content, mediaContent);
      initialize(result);
      return result;
    }

    public class Insert extends BigqueryRequest<com.google.api.services.bigquery.model.Job> {

      private static final String REST_PATH = "projects/{projectId}/jobs";

      /**
       * Starts a new asynchronous job.
       *
       * Create a request for the method "jobs.insert".
       *
       * This request holds the parameters needed by the the bigquery server.  After setting any
       * optional parameters, call the {@link Insert#execute()} method to invoke the remote operation.
       * <p> {@link Insert#initialize(AbstractGoogleClientRequest)} must be called to initialize this
       * instance immediately after invoking the constructor. </p>
       *
       * @param projectId Project ID of the project that will be billed for the job
       * @param content the {@link com.google.api.services.bigquery.model.Job}
       * @since 1.13
       */
      protected Insert(String projectId, com.google.api.services.bigquery.model.Job content) {
        super(Bigquery.this, "POST", REST_PATH, content, com.google.api.services.bigquery.model.Job.class);
        this.projectId = Preconditions.checkNotNull(projectId, "Required parameter projectId must be specified.");
      }

      /**
       * Starts a new asynchronous job.
       *
       * Create a request for the method "jobs.insert".
       *
       * This request holds the parameters needed by the the bigquery server.  After setting any
       * optional parameters, call the {@link Insert#execute()} method to invoke the remote operation.
       * <p> {@link Insert#initialize(AbstractGoogleClientRequest)} must be called to initialize this
       * instance immediately after invoking the constructor. </p>
       *
       * <p>
       * This constructor should be used for uploading media content.
       * </p>
       *
       * @param projectId Project ID of the project that will be billed for the job
       * @param content the {@link com.google.api.services.bigquery.model.Job} media metadata or {@code null} if none
       * @param mediaContent The media HTTP content or {@code null} if none.
       * @since 1.13
       */
      protected Insert(String projectId, com.google.api.services.bigquery.model.Job content,
          com.google.api.client.http.AbstractInputStreamContent mediaContent) {
        super(Bigquery.this, "POST", "/upload/" + getServicePath() + REST_PATH, content, com.google.api.services.bigquery.model.Job.class);
        this.projectId = Preconditions.checkNotNull(projectId, "Required parameter projectId must be specified.");
        initializeMediaUpload(mediaContent);
      }

      @Override
      public Insert setAlt(String alt) {
        return (Insert) super.setAlt(alt);
      }

      @Override
      public Insert setFields(String fields) {
        return (Insert) super.setFields(fields);
      }

      @Override
      public Insert setKey(String key) {
        return (Insert) super.setKey(key);
      }

      @Override
      public Insert setOauthToken(String oauthToken) {
        return (Insert) super.setOauthToken(oauthToken);
      }

      @Override
      public Insert setPrettyPrint(Boolean prettyPrint) {
        return (Insert) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public Insert setQuotaUser(String quotaUser) {
        return (Insert) super.setQuotaUser(quotaUser);
      }

      @Override
      public Insert setUserIp(String userIp) {
        return (Insert) super.setUserIp(userIp);
      }

      /** Project ID of the project that will be billed for the job */
      @com.google.api.client.util.Key
      private String projectId;

      /** Project ID of the project that will be billed for the job
       */
      public String getProjectId() {
        return projectId;
      }

      /** Project ID of the project that will be billed for the job */
      public Insert setProjectId(String projectId) {
        this.projectId = projectId;
        return this;
      }

    }
    /**
     * Lists all the Jobs in the specified project that were started by the user.
     *
     * Create a request for the method "jobs.list".
     *
     * This request holds the parameters needed by the the bigquery server.  After setting any optional
     * parameters, call the {@link List#execute()} method to invoke the remote operation.
     *
     * @param projectId Project ID of the jobs to list
     * @return the request
     */
    public List list(String projectId) throws java.io.IOException {
      List result = new List(projectId);
      initialize(result);
      return result;
    }

    public class List extends BigqueryRequest<com.google.api.services.bigquery.model.JobList> {

      private static final String REST_PATH = "projects/{projectId}/jobs";

      /**
       * Lists all the Jobs in the specified project that were started by the user.
       *
       * Create a request for the method "jobs.list".
       *
       * This request holds the parameters needed by the the bigquery server.  After setting any
       * optional parameters, call the {@link List#execute()} method to invoke the remote operation. <p>
       * {@link List#initialize(AbstractGoogleClientRequest)} must be called to initialize this instance
       * immediately after invoking the constructor. </p>
       *
       * @param projectId Project ID of the jobs to list
       * @since 1.13
       */
      protected List(String projectId) {
        super(Bigquery.this, "GET", REST_PATH, null, com.google.api.services.bigquery.model.JobList.class);
        this.projectId = Preconditions.checkNotNull(projectId, "Required parameter projectId must be specified.");
      }

      @Override
      public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
        return super.executeUsingHead();
      }

      @Override
      public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
        return super.buildHttpRequestUsingHead();
      }

      @Override
      public List setAlt(String alt) {
        return (List) super.setAlt(alt);
      }

      @Override
      public List setFields(String fields) {
        return (List) super.setFields(fields);
      }

      @Override
      public List setKey(String key) {
        return (List) super.setKey(key);
      }

      @Override
      public List setOauthToken(String oauthToken) {
        return (List) super.setOauthToken(oauthToken);
      }

      @Override
      public List setPrettyPrint(Boolean prettyPrint) {
        return (List) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public List setQuotaUser(String quotaUser) {
        return (List) super.setQuotaUser(quotaUser);
      }

      @Override
      public List setUserIp(String userIp) {
        return (List) super.setUserIp(userIp);
      }

      /** Project ID of the jobs to list */
      @com.google.api.client.util.Key
      private String projectId;

      /** Project ID of the jobs to list
       */
      public String getProjectId() {
        return projectId;
      }

      /** Project ID of the jobs to list */
      public List setProjectId(String projectId) {
        this.projectId = projectId;
        return this;
      }

      /** Restrict information returned to a set of selected fields */
      @com.google.api.client.util.Key
      private String projection;

      /** Restrict information returned to a set of selected fields
       */
      public String getProjection() {
        return projection;
      }

      /** Restrict information returned to a set of selected fields */
      public List setProjection(String projection) {
        this.projection = projection;
        return this;
      }

      /** Filter for job state */
      @com.google.api.client.util.Key
      private java.util.List<String> stateFilter;

      /** Filter for job state
       */
      public java.util.List<String> getStateFilter() {
        return stateFilter;
      }

      /** Filter for job state */
      public List setStateFilter(java.util.List<String> stateFilter) {
        this.stateFilter = stateFilter;
        return this;
      }

      /** Whether to display jobs owned by all users in the project. Default false */
      @com.google.api.client.util.Key
      private Boolean allUsers;

      /** Whether to display jobs owned by all users in the project. Default false
       */
      public Boolean getAllUsers() {
        return allUsers;
      }

      /** Whether to display jobs owned by all users in the project. Default false */
      public List setAllUsers(Boolean allUsers) {
        this.allUsers = allUsers;
        return this;
      }

      /** Maximum number of results to return */
      @com.google.api.client.util.Key
      private Long maxResults;

      /** Maximum number of results to return
       */
      public Long getMaxResults() {
        return maxResults;
      }

      /** Maximum number of results to return */
      public List setMaxResults(Long maxResults) {
        this.maxResults = maxResults;
        return this;
      }

      /** Page token, returned by a previous call, to request the next page of results */
      @com.google.api.client.util.Key
      private String pageToken;

      /** Page token, returned by a previous call, to request the next page of results
       */
      public String getPageToken() {
        return pageToken;
      }

      /** Page token, returned by a previous call, to request the next page of results */
      public List setPageToken(String pageToken) {
        this.pageToken = pageToken;
        return this;
      }

    }
    /**
     * Runs a BigQuery SQL query synchronously and returns query results if the query completes within a
     * specified timeout.
     *
     * Create a request for the method "jobs.query".
     *
     * This request holds the parameters needed by the the bigquery server.  After setting any optional
     * parameters, call the {@link Query#execute()} method to invoke the remote operation.
     *
     * @param projectId Project ID of the project billed for the query
     * @param content the {@link com.google.api.services.bigquery.model.QueryRequest}
     * @return the request
     */
    public Query query(String projectId, com.google.api.services.bigquery.model.QueryRequest content) throws java.io.IOException {
      Query result = new Query(projectId, content);
      initialize(result);
      return result;
    }

    public class Query extends BigqueryRequest<com.google.api.services.bigquery.model.QueryResponse> {

      private static final String REST_PATH = "projects/{projectId}/queries";

      /**
       * Runs a BigQuery SQL query synchronously and returns query results if the query completes within
       * a specified timeout.
       *
       * Create a request for the method "jobs.query".
       *
       * This request holds the parameters needed by the the bigquery server.  After setting any
       * optional parameters, call the {@link Query#execute()} method to invoke the remote operation.
       * <p> {@link Query#initialize(AbstractGoogleClientRequest)} must be called to initialize this
       * instance immediately after invoking the constructor. </p>
       *
       * @param projectId Project ID of the project billed for the query
       * @param content the {@link com.google.api.services.bigquery.model.QueryRequest}
       * @since 1.13
       */
      protected Query(String projectId, com.google.api.services.bigquery.model.QueryRequest content) {
        super(Bigquery.this, "POST", REST_PATH, content, com.google.api.services.bigquery.model.QueryResponse.class);
        this.projectId = Preconditions.checkNotNull(projectId, "Required parameter projectId must be specified.");
      }

      @Override
      public Query setAlt(String alt) {
        return (Query) super.setAlt(alt);
      }

      @Override
      public Query setFields(String fields) {
        return (Query) super.setFields(fields);
      }

      @Override
      public Query setKey(String key) {
        return (Query) super.setKey(key);
      }

      @Override
      public Query setOauthToken(String oauthToken) {
        return (Query) super.setOauthToken(oauthToken);
      }

      @Override
      public Query setPrettyPrint(Boolean prettyPrint) {
        return (Query) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public Query setQuotaUser(String quotaUser) {
        return (Query) super.setQuotaUser(quotaUser);
      }

      @Override
      public Query setUserIp(String userIp) {
        return (Query) super.setUserIp(userIp);
      }

      /** Project ID of the project billed for the query */
      @com.google.api.client.util.Key
      private String projectId;

      /** Project ID of the project billed for the query
       */
      public String getProjectId() {
        return projectId;
      }

      /** Project ID of the project billed for the query */
      public Query setProjectId(String projectId) {
        this.projectId = projectId;
        return this;
      }

    }

  }

  /**
   * An accessor for creating requests from the Projects collection.
   *
   * <p>The typical use is:</p>
   * <pre>
   *   {@code Bigquery bigquery = new Bigquery(...);}
   *   {@code Bigquery.Projects.List request = bigquery.projects().list(parameters ...)}
   * </pre>
   *
   * @return the resource collection
   */
  public Projects projects() {
    return new Projects();
  }

  /**
   * The "projects" collection of methods.
   */
  public class Projects {

    /**
     * Lists the projects to which you have at least read access.
     *
     * Create a request for the method "projects.list".
     *
     * This request holds the parameters needed by the the bigquery server.  After setting any optional
     * parameters, call the {@link List#execute()} method to invoke the remote operation.
     *
     * @return the request
     */
    public List list() throws java.io.IOException {
      List result = new List();
      initialize(result);
      return result;
    }

    public class List extends BigqueryRequest<com.google.api.services.bigquery.model.ProjectList> {

      private static final String REST_PATH = "projects";

      /**
       * Lists the projects to which you have at least read access.
       *
       * Create a request for the method "projects.list".
       *
       * This request holds the parameters needed by the the bigquery server.  After setting any
       * optional parameters, call the {@link List#execute()} method to invoke the remote operation. <p>
       * {@link List#initialize(AbstractGoogleClientRequest)} must be called to initialize this instance
       * immediately after invoking the constructor. </p>
       *
       * @since 1.13
       */
      protected List() {
        super(Bigquery.this, "GET", REST_PATH, null, com.google.api.services.bigquery.model.ProjectList.class);
      }

      @Override
      public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
        return super.executeUsingHead();
      }

      @Override
      public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
        return super.buildHttpRequestUsingHead();
      }

      @Override
      public List setAlt(String alt) {
        return (List) super.setAlt(alt);
      }

      @Override
      public List setFields(String fields) {
        return (List) super.setFields(fields);
      }

      @Override
      public List setKey(String key) {
        return (List) super.setKey(key);
      }

      @Override
      public List setOauthToken(String oauthToken) {
        return (List) super.setOauthToken(oauthToken);
      }

      @Override
      public List setPrettyPrint(Boolean prettyPrint) {
        return (List) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public List setQuotaUser(String quotaUser) {
        return (List) super.setQuotaUser(quotaUser);
      }

      @Override
      public List setUserIp(String userIp) {
        return (List) super.setUserIp(userIp);
      }

      /** Page token, returned by a previous call, to request the next page of results */
      @com.google.api.client.util.Key
      private String pageToken;

      /** Page token, returned by a previous call, to request the next page of results
       */
      public String getPageToken() {
        return pageToken;
      }

      /** Page token, returned by a previous call, to request the next page of results */
      public List setPageToken(String pageToken) {
        this.pageToken = pageToken;
        return this;
      }

      /** Maximum number of results to return */
      @com.google.api.client.util.Key
      private Long maxResults;

      /** Maximum number of results to return
       */
      public Long getMaxResults() {
        return maxResults;
      }

      /** Maximum number of results to return */
      public List setMaxResults(Long maxResults) {
        this.maxResults = maxResults;
        return this;
      }

    }

  }

  /**
   * An accessor for creating requests from the Tabledata collection.
   *
   * <p>The typical use is:</p>
   * <pre>
   *   {@code Bigquery bigquery = new Bigquery(...);}
   *   {@code Bigquery.Tabledata.List request = bigquery.tabledata().list(parameters ...)}
   * </pre>
   *
   * @return the resource collection
   */
  public Tabledata tabledata() {
    return new Tabledata();
  }

  /**
   * The "tabledata" collection of methods.
   */
  public class Tabledata {

    /**
     * Retrieves table data from a specified set of rows.
     *
     * Create a request for the method "tabledata.list".
     *
     * This request holds the parameters needed by the the bigquery server.  After setting any optional
     * parameters, call the {@link List#execute()} method to invoke the remote operation.
     *
     * @param projectId Project ID of the table to read
     * @param datasetId Dataset ID of the table to read
     * @param tableId Table ID of the table to read
     * @return the request
     */
    public List list(String projectId, String datasetId, String tableId) throws java.io.IOException {
      List result = new List(projectId, datasetId, tableId);
      initialize(result);
      return result;
    }

    public class List extends BigqueryRequest<com.google.api.services.bigquery.model.TableDataList> {

      private static final String REST_PATH = "projects/{projectId}/datasets/{datasetId}/tables/{tableId}/data";

      /**
       * Retrieves table data from a specified set of rows.
       *
       * Create a request for the method "tabledata.list".
       *
       * This request holds the parameters needed by the the bigquery server.  After setting any
       * optional parameters, call the {@link List#execute()} method to invoke the remote operation. <p>
       * {@link List#initialize(AbstractGoogleClientRequest)} must be called to initialize this instance
       * immediately after invoking the constructor. </p>
       *
       * @param projectId Project ID of the table to read
       * @param datasetId Dataset ID of the table to read
       * @param tableId Table ID of the table to read
       * @since 1.13
       */
      protected List(String projectId, String datasetId, String tableId) {
        super(Bigquery.this, "GET", REST_PATH, null, com.google.api.services.bigquery.model.TableDataList.class);
        this.projectId = Preconditions.checkNotNull(projectId, "Required parameter projectId must be specified.");
        this.datasetId = Preconditions.checkNotNull(datasetId, "Required parameter datasetId must be specified.");
        this.tableId = Preconditions.checkNotNull(tableId, "Required parameter tableId must be specified.");
      }

      @Override
      public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
        return super.executeUsingHead();
      }

      @Override
      public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
        return super.buildHttpRequestUsingHead();
      }

      @Override
      public List setAlt(String alt) {
        return (List) super.setAlt(alt);
      }

      @Override
      public List setFields(String fields) {
        return (List) super.setFields(fields);
      }

      @Override
      public List setKey(String key) {
        return (List) super.setKey(key);
      }

      @Override
      public List setOauthToken(String oauthToken) {
        return (List) super.setOauthToken(oauthToken);
      }

      @Override
      public List setPrettyPrint(Boolean prettyPrint) {
        return (List) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public List setQuotaUser(String quotaUser) {
        return (List) super.setQuotaUser(quotaUser);
      }

      @Override
      public List setUserIp(String userIp) {
        return (List) super.setUserIp(userIp);
      }

      /** Project ID of the table to read */
      @com.google.api.client.util.Key
      private String projectId;

      /** Project ID of the table to read
       */
      public String getProjectId() {
        return projectId;
      }

      /** Project ID of the table to read */
      public List setProjectId(String projectId) {
        this.projectId = projectId;
        return this;
      }

      /** Dataset ID of the table to read */
      @com.google.api.client.util.Key
      private String datasetId;

      /** Dataset ID of the table to read
       */
      public String getDatasetId() {
        return datasetId;
      }

      /** Dataset ID of the table to read */
      public List setDatasetId(String datasetId) {
        this.datasetId = datasetId;
        return this;
      }

      /** Table ID of the table to read */
      @com.google.api.client.util.Key
      private String tableId;

      /** Table ID of the table to read
       */
      public String getTableId() {
        return tableId;
      }

      /** Table ID of the table to read */
      public List setTableId(String tableId) {
        this.tableId = tableId;
        return this;
      }

      /** Maximum number of results to return */
      @com.google.api.client.util.Key
      private Long maxResults;

      /** Maximum number of results to return
       */
      public Long getMaxResults() {
        return maxResults;
      }

      /** Maximum number of results to return */
      public List setMaxResults(Long maxResults) {
        this.maxResults = maxResults;
        return this;
      }

      /** Page token, returned by a previous call, identifying the result set */
      @com.google.api.client.util.Key
      private String pageToken;

      /** Page token, returned by a previous call, identifying the result set
       */
      public String getPageToken() {
        return pageToken;
      }

      /** Page token, returned by a previous call, identifying the result set */
      public List setPageToken(String pageToken) {
        this.pageToken = pageToken;
        return this;
      }

      /** Zero-based index of the starting row to read */
      @com.google.api.client.util.Key
      private UnsignedLong startIndex;

      /** Zero-based index of the starting row to read
       */
      public UnsignedLong getStartIndex() {
        return startIndex;
      }

      /** Zero-based index of the starting row to read */
      public List setStartIndex(UnsignedLong startIndex) {
        this.startIndex = startIndex;
        return this;
      }

    }

  }

  /**
   * An accessor for creating requests from the Tables collection.
   *
   * <p>The typical use is:</p>
   * <pre>
   *   {@code Bigquery bigquery = new Bigquery(...);}
   *   {@code Bigquery.Tables.List request = bigquery.tables().list(parameters ...)}
   * </pre>
   *
   * @return the resource collection
   */
  public Tables tables() {
    return new Tables();
  }

  /**
   * The "tables" collection of methods.
   */
  public class Tables {

    /**
     * Deletes the table specified by tableId from the dataset. If the table contains data, all the data
     * will be deleted.
     *
     * Create a request for the method "tables.delete".
     *
     * This request holds the parameters needed by the the bigquery server.  After setting any optional
     * parameters, call the {@link Delete#execute()} method to invoke the remote operation.
     *
     * @param projectId Project ID of the table to delete
     * @param datasetId Dataset ID of the table to delete
     * @param tableId Table ID of the table to delete
     * @return the request
     */
    public Delete delete(String projectId, String datasetId, String tableId) throws java.io.IOException {
      Delete result = new Delete(projectId, datasetId, tableId);
      initialize(result);
      return result;
    }

    public class Delete extends BigqueryRequest<Void> {

      private static final String REST_PATH = "projects/{projectId}/datasets/{datasetId}/tables/{tableId}";

      /**
       * Deletes the table specified by tableId from the dataset. If the table contains data, all the
       * data will be deleted.
       *
       * Create a request for the method "tables.delete".
       *
       * This request holds the parameters needed by the the bigquery server.  After setting any
       * optional parameters, call the {@link Delete#execute()} method to invoke the remote operation.
       * <p> {@link Delete#initialize(AbstractGoogleClientRequest)} must be called to initialize this
       * instance immediately after invoking the constructor. </p>
       *
       * @param projectId Project ID of the table to delete
       * @param datasetId Dataset ID of the table to delete
       * @param tableId Table ID of the table to delete
       * @since 1.13
       */
      protected Delete(String projectId, String datasetId, String tableId) {
        super(Bigquery.this, "DELETE", REST_PATH, null, Void.class);
        this.projectId = Preconditions.checkNotNull(projectId, "Required parameter projectId must be specified.");
        this.datasetId = Preconditions.checkNotNull(datasetId, "Required parameter datasetId must be specified.");
        this.tableId = Preconditions.checkNotNull(tableId, "Required parameter tableId must be specified.");
      }

      @Override
      public Delete setAlt(String alt) {
        return (Delete) super.setAlt(alt);
      }

      @Override
      public Delete setFields(String fields) {
        return (Delete) super.setFields(fields);
      }

      @Override
      public Delete setKey(String key) {
        return (Delete) super.setKey(key);
      }

      @Override
      public Delete setOauthToken(String oauthToken) {
        return (Delete) super.setOauthToken(oauthToken);
      }

      @Override
      public Delete setPrettyPrint(Boolean prettyPrint) {
        return (Delete) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public Delete setQuotaUser(String quotaUser) {
        return (Delete) super.setQuotaUser(quotaUser);
      }

      @Override
      public Delete setUserIp(String userIp) {
        return (Delete) super.setUserIp(userIp);
      }

      /** Project ID of the table to delete */
      @com.google.api.client.util.Key
      private String projectId;

      /** Project ID of the table to delete
       */
      public String getProjectId() {
        return projectId;
      }

      /** Project ID of the table to delete */
      public Delete setProjectId(String projectId) {
        this.projectId = projectId;
        return this;
      }

      /** Dataset ID of the table to delete */
      @com.google.api.client.util.Key
      private String datasetId;

      /** Dataset ID of the table to delete
       */
      public String getDatasetId() {
        return datasetId;
      }

      /** Dataset ID of the table to delete */
      public Delete setDatasetId(String datasetId) {
        this.datasetId = datasetId;
        return this;
      }

      /** Table ID of the table to delete */
      @com.google.api.client.util.Key
      private String tableId;

      /** Table ID of the table to delete
       */
      public String getTableId() {
        return tableId;
      }

      /** Table ID of the table to delete */
      public Delete setTableId(String tableId) {
        this.tableId = tableId;
        return this;
      }

    }
    /**
     * Gets the specified table resource by table ID. This method does not return the data in the table,
     * it only returns the table resource, which describes the structure of this table.
     *
     * Create a request for the method "tables.get".
     *
     * This request holds the parameters needed by the the bigquery server.  After setting any optional
     * parameters, call the {@link Get#execute()} method to invoke the remote operation.
     *
     * @param projectId Project ID of the requested table
     * @param datasetId Dataset ID of the requested table
     * @param tableId Table ID of the requested table
     * @return the request
     */
    public Get get(String projectId, String datasetId, String tableId) throws java.io.IOException {
      Get result = new Get(projectId, datasetId, tableId);
      initialize(result);
      return result;
    }

    public class Get extends BigqueryRequest<com.google.api.services.bigquery.model.Table> {

      private static final String REST_PATH = "projects/{projectId}/datasets/{datasetId}/tables/{tableId}";

      /**
       * Gets the specified table resource by table ID. This method does not return the data in the
       * table, it only returns the table resource, which describes the structure of this table.
       *
       * Create a request for the method "tables.get".
       *
       * This request holds the parameters needed by the the bigquery server.  After setting any
       * optional parameters, call the {@link Get#execute()} method to invoke the remote operation. <p>
       * {@link Get#initialize(AbstractGoogleClientRequest)} must be called to initialize this instance
       * immediately after invoking the constructor. </p>
       *
       * @param projectId Project ID of the requested table
       * @param datasetId Dataset ID of the requested table
       * @param tableId Table ID of the requested table
       * @since 1.13
       */
      protected Get(String projectId, String datasetId, String tableId) {
        super(Bigquery.this, "GET", REST_PATH, null, com.google.api.services.bigquery.model.Table.class);
        this.projectId = Preconditions.checkNotNull(projectId, "Required parameter projectId must be specified.");
        this.datasetId = Preconditions.checkNotNull(datasetId, "Required parameter datasetId must be specified.");
        this.tableId = Preconditions.checkNotNull(tableId, "Required parameter tableId must be specified.");
      }

      @Override
      public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
        return super.executeUsingHead();
      }

      @Override
      public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
        return super.buildHttpRequestUsingHead();
      }

      @Override
      public Get setAlt(String alt) {
        return (Get) super.setAlt(alt);
      }

      @Override
      public Get setFields(String fields) {
        return (Get) super.setFields(fields);
      }

      @Override
      public Get setKey(String key) {
        return (Get) super.setKey(key);
      }

      @Override
      public Get setOauthToken(String oauthToken) {
        return (Get) super.setOauthToken(oauthToken);
      }

      @Override
      public Get setPrettyPrint(Boolean prettyPrint) {
        return (Get) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public Get setQuotaUser(String quotaUser) {
        return (Get) super.setQuotaUser(quotaUser);
      }

      @Override
      public Get setUserIp(String userIp) {
        return (Get) super.setUserIp(userIp);
      }

      /** Project ID of the requested table */
      @com.google.api.client.util.Key
      private String projectId;

      /** Project ID of the requested table
       */
      public String getProjectId() {
        return projectId;
      }

      /** Project ID of the requested table */
      public Get setProjectId(String projectId) {
        this.projectId = projectId;
        return this;
      }

      /** Dataset ID of the requested table */
      @com.google.api.client.util.Key
      private String datasetId;

      /** Dataset ID of the requested table
       */
      public String getDatasetId() {
        return datasetId;
      }

      /** Dataset ID of the requested table */
      public Get setDatasetId(String datasetId) {
        this.datasetId = datasetId;
        return this;
      }

      /** Table ID of the requested table */
      @com.google.api.client.util.Key
      private String tableId;

      /** Table ID of the requested table
       */
      public String getTableId() {
        return tableId;
      }

      /** Table ID of the requested table */
      public Get setTableId(String tableId) {
        this.tableId = tableId;
        return this;
      }

    }
    /**
     * Creates a new, empty table in the dataset.
     *
     * Create a request for the method "tables.insert".
     *
     * This request holds the parameters needed by the the bigquery server.  After setting any optional
     * parameters, call the {@link Insert#execute()} method to invoke the remote operation.
     *
     * @param projectId Project ID of the new table
     * @param datasetId Dataset ID of the new table
     * @param content the {@link com.google.api.services.bigquery.model.Table}
     * @return the request
     */
    public Insert insert(String projectId, String datasetId, com.google.api.services.bigquery.model.Table content) throws java.io.IOException {
      Insert result = new Insert(projectId, datasetId, content);
      initialize(result);
      return result;
    }

    public class Insert extends BigqueryRequest<com.google.api.services.bigquery.model.Table> {

      private static final String REST_PATH = "projects/{projectId}/datasets/{datasetId}/tables";

      /**
       * Creates a new, empty table in the dataset.
       *
       * Create a request for the method "tables.insert".
       *
       * This request holds the parameters needed by the the bigquery server.  After setting any
       * optional parameters, call the {@link Insert#execute()} method to invoke the remote operation.
       * <p> {@link Insert#initialize(AbstractGoogleClientRequest)} must be called to initialize this
       * instance immediately after invoking the constructor. </p>
       *
       * @param projectId Project ID of the new table
       * @param datasetId Dataset ID of the new table
       * @param content the {@link com.google.api.services.bigquery.model.Table}
       * @since 1.13
       */
      protected Insert(String projectId, String datasetId, com.google.api.services.bigquery.model.Table content) {
        super(Bigquery.this, "POST", REST_PATH, content, com.google.api.services.bigquery.model.Table.class);
        this.projectId = Preconditions.checkNotNull(projectId, "Required parameter projectId must be specified.");
        this.datasetId = Preconditions.checkNotNull(datasetId, "Required parameter datasetId must be specified.");
      }

      @Override
      public Insert setAlt(String alt) {
        return (Insert) super.setAlt(alt);
      }

      @Override
      public Insert setFields(String fields) {
        return (Insert) super.setFields(fields);
      }

      @Override
      public Insert setKey(String key) {
        return (Insert) super.setKey(key);
      }

      @Override
      public Insert setOauthToken(String oauthToken) {
        return (Insert) super.setOauthToken(oauthToken);
      }

      @Override
      public Insert setPrettyPrint(Boolean prettyPrint) {
        return (Insert) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public Insert setQuotaUser(String quotaUser) {
        return (Insert) super.setQuotaUser(quotaUser);
      }

      @Override
      public Insert setUserIp(String userIp) {
        return (Insert) super.setUserIp(userIp);
      }

      /** Project ID of the new table */
      @com.google.api.client.util.Key
      private String projectId;

      /** Project ID of the new table
       */
      public String getProjectId() {
        return projectId;
      }

      /** Project ID of the new table */
      public Insert setProjectId(String projectId) {
        this.projectId = projectId;
        return this;
      }

      /** Dataset ID of the new table */
      @com.google.api.client.util.Key
      private String datasetId;

      /** Dataset ID of the new table
       */
      public String getDatasetId() {
        return datasetId;
      }

      /** Dataset ID of the new table */
      public Insert setDatasetId(String datasetId) {
        this.datasetId = datasetId;
        return this;
      }

    }
    /**
     * Lists all tables in the specified dataset.
     *
     * Create a request for the method "tables.list".
     *
     * This request holds the parameters needed by the the bigquery server.  After setting any optional
     * parameters, call the {@link List#execute()} method to invoke the remote operation.
     *
     * @param projectId Project ID of the tables to list
     * @param datasetId Dataset ID of the tables to list
     * @return the request
     */
    public List list(String projectId, String datasetId) throws java.io.IOException {
      List result = new List(projectId, datasetId);
      initialize(result);
      return result;
    }

    public class List extends BigqueryRequest<com.google.api.services.bigquery.model.TableList> {

      private static final String REST_PATH = "projects/{projectId}/datasets/{datasetId}/tables";

      /**
       * Lists all tables in the specified dataset.
       *
       * Create a request for the method "tables.list".
       *
       * This request holds the parameters needed by the the bigquery server.  After setting any
       * optional parameters, call the {@link List#execute()} method to invoke the remote operation. <p>
       * {@link List#initialize(AbstractGoogleClientRequest)} must be called to initialize this instance
       * immediately after invoking the constructor. </p>
       *
       * @param projectId Project ID of the tables to list
       * @param datasetId Dataset ID of the tables to list
       * @since 1.13
       */
      protected List(String projectId, String datasetId) {
        super(Bigquery.this, "GET", REST_PATH, null, com.google.api.services.bigquery.model.TableList.class);
        this.projectId = Preconditions.checkNotNull(projectId, "Required parameter projectId must be specified.");
        this.datasetId = Preconditions.checkNotNull(datasetId, "Required parameter datasetId must be specified.");
      }

      @Override
      public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
        return super.executeUsingHead();
      }

      @Override
      public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
        return super.buildHttpRequestUsingHead();
      }

      @Override
      public List setAlt(String alt) {
        return (List) super.setAlt(alt);
      }

      @Override
      public List setFields(String fields) {
        return (List) super.setFields(fields);
      }

      @Override
      public List setKey(String key) {
        return (List) super.setKey(key);
      }

      @Override
      public List setOauthToken(String oauthToken) {
        return (List) super.setOauthToken(oauthToken);
      }

      @Override
      public List setPrettyPrint(Boolean prettyPrint) {
        return (List) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public List setQuotaUser(String quotaUser) {
        return (List) super.setQuotaUser(quotaUser);
      }

      @Override
      public List setUserIp(String userIp) {
        return (List) super.setUserIp(userIp);
      }

      /** Project ID of the tables to list */
      @com.google.api.client.util.Key
      private String projectId;

      /** Project ID of the tables to list
       */
      public String getProjectId() {
        return projectId;
      }

      /** Project ID of the tables to list */
      public List setProjectId(String projectId) {
        this.projectId = projectId;
        return this;
      }

      /** Dataset ID of the tables to list */
      @com.google.api.client.util.Key
      private String datasetId;

      /** Dataset ID of the tables to list
       */
      public String getDatasetId() {
        return datasetId;
      }

      /** Dataset ID of the tables to list */
      public List setDatasetId(String datasetId) {
        this.datasetId = datasetId;
        return this;
      }

      /** Page token, returned by a previous call, to request the next page of results */
      @com.google.api.client.util.Key
      private String pageToken;

      /** Page token, returned by a previous call, to request the next page of results
       */
      public String getPageToken() {
        return pageToken;
      }

      /** Page token, returned by a previous call, to request the next page of results */
      public List setPageToken(String pageToken) {
        this.pageToken = pageToken;
        return this;
      }

      /** Maximum number of results to return */
      @com.google.api.client.util.Key
      private Long maxResults;

      /** Maximum number of results to return
       */
      public Long getMaxResults() {
        return maxResults;
      }

      /** Maximum number of results to return */
      public List setMaxResults(Long maxResults) {
        this.maxResults = maxResults;
        return this;
      }

    }
    /**
     * Updates information in an existing table, specified by tableId. This method supports patch
     * semantics.
     *
     * Create a request for the method "tables.patch".
     *
     * This request holds the parameters needed by the the bigquery server.  After setting any optional
     * parameters, call the {@link Patch#execute()} method to invoke the remote operation.
     *
     * @param projectId Project ID of the table to update
     * @param datasetId Dataset ID of the table to update
     * @param tableId Table ID of the table to update
     * @param content the {@link com.google.api.services.bigquery.model.Table}
     * @return the request
     */
    public Patch patch(String projectId, String datasetId, String tableId, com.google.api.services.bigquery.model.Table content) throws java.io.IOException {
      Patch result = new Patch(projectId, datasetId, tableId, content);
      initialize(result);
      return result;
    }

    public class Patch extends BigqueryRequest<com.google.api.services.bigquery.model.Table> {

      private static final String REST_PATH = "projects/{projectId}/datasets/{datasetId}/tables/{tableId}";

      /**
       * Updates information in an existing table, specified by tableId. This method supports patch
       * semantics.
       *
       * Create a request for the method "tables.patch".
       *
       * This request holds the parameters needed by the the bigquery server.  After setting any
       * optional parameters, call the {@link Patch#execute()} method to invoke the remote operation.
       * <p> {@link Patch#initialize(AbstractGoogleClientRequest)} must be called to initialize this
       * instance immediately after invoking the constructor. </p>
       *
       * @param projectId Project ID of the table to update
       * @param datasetId Dataset ID of the table to update
       * @param tableId Table ID of the table to update
       * @param content the {@link com.google.api.services.bigquery.model.Table}
       * @since 1.13
       */
      protected Patch(String projectId, String datasetId, String tableId, com.google.api.services.bigquery.model.Table content) {
        super(Bigquery.this, "PATCH", REST_PATH, content, com.google.api.services.bigquery.model.Table.class);
        this.projectId = Preconditions.checkNotNull(projectId, "Required parameter projectId must be specified.");
        this.datasetId = Preconditions.checkNotNull(datasetId, "Required parameter datasetId must be specified.");
        this.tableId = Preconditions.checkNotNull(tableId, "Required parameter tableId must be specified.");
      }

      @Override
      public Patch setAlt(String alt) {
        return (Patch) super.setAlt(alt);
      }

      @Override
      public Patch setFields(String fields) {
        return (Patch) super.setFields(fields);
      }

      @Override
      public Patch setKey(String key) {
        return (Patch) super.setKey(key);
      }

      @Override
      public Patch setOauthToken(String oauthToken) {
        return (Patch) super.setOauthToken(oauthToken);
      }

      @Override
      public Patch setPrettyPrint(Boolean prettyPrint) {
        return (Patch) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public Patch setQuotaUser(String quotaUser) {
        return (Patch) super.setQuotaUser(quotaUser);
      }

      @Override
      public Patch setUserIp(String userIp) {
        return (Patch) super.setUserIp(userIp);
      }

      /** Project ID of the table to update */
      @com.google.api.client.util.Key
      private String projectId;

      /** Project ID of the table to update
       */
      public String getProjectId() {
        return projectId;
      }

      /** Project ID of the table to update */
      public Patch setProjectId(String projectId) {
        this.projectId = projectId;
        return this;
      }

      /** Dataset ID of the table to update */
      @com.google.api.client.util.Key
      private String datasetId;

      /** Dataset ID of the table to update
       */
      public String getDatasetId() {
        return datasetId;
      }

      /** Dataset ID of the table to update */
      public Patch setDatasetId(String datasetId) {
        this.datasetId = datasetId;
        return this;
      }

      /** Table ID of the table to update */
      @com.google.api.client.util.Key
      private String tableId;

      /** Table ID of the table to update
       */
      public String getTableId() {
        return tableId;
      }

      /** Table ID of the table to update */
      public Patch setTableId(String tableId) {
        this.tableId = tableId;
        return this;
      }

    }
    /**
     * Updates information in an existing table, specified by tableId.
     *
     * Create a request for the method "tables.update".
     *
     * This request holds the parameters needed by the the bigquery server.  After setting any optional
     * parameters, call the {@link Update#execute()} method to invoke the remote operation.
     *
     * @param projectId Project ID of the table to update
     * @param datasetId Dataset ID of the table to update
     * @param tableId Table ID of the table to update
     * @param content the {@link com.google.api.services.bigquery.model.Table}
     * @return the request
     */
    public Update update(String projectId, String datasetId, String tableId, com.google.api.services.bigquery.model.Table content) throws java.io.IOException {
      Update result = new Update(projectId, datasetId, tableId, content);
      initialize(result);
      return result;
    }

    public class Update extends BigqueryRequest<com.google.api.services.bigquery.model.Table> {

      private static final String REST_PATH = "projects/{projectId}/datasets/{datasetId}/tables/{tableId}";

      /**
       * Updates information in an existing table, specified by tableId.
       *
       * Create a request for the method "tables.update".
       *
       * This request holds the parameters needed by the the bigquery server.  After setting any
       * optional parameters, call the {@link Update#execute()} method to invoke the remote operation.
       * <p> {@link Update#initialize(AbstractGoogleClientRequest)} must be called to initialize this
       * instance immediately after invoking the constructor. </p>
       *
       * @param projectId Project ID of the table to update
       * @param datasetId Dataset ID of the table to update
       * @param tableId Table ID of the table to update
       * @param content the {@link com.google.api.services.bigquery.model.Table}
       * @since 1.13
       */
      protected Update(String projectId, String datasetId, String tableId, com.google.api.services.bigquery.model.Table content) {
        super(Bigquery.this, "PUT", REST_PATH, content, com.google.api.services.bigquery.model.Table.class);
        this.projectId = Preconditions.checkNotNull(projectId, "Required parameter projectId must be specified.");
        this.datasetId = Preconditions.checkNotNull(datasetId, "Required parameter datasetId must be specified.");
        this.tableId = Preconditions.checkNotNull(tableId, "Required parameter tableId must be specified.");
      }

      @Override
      public Update setAlt(String alt) {
        return (Update) super.setAlt(alt);
      }

      @Override
      public Update setFields(String fields) {
        return (Update) super.setFields(fields);
      }

      @Override
      public Update setKey(String key) {
        return (Update) super.setKey(key);
      }

      @Override
      public Update setOauthToken(String oauthToken) {
        return (Update) super.setOauthToken(oauthToken);
      }

      @Override
      public Update setPrettyPrint(Boolean prettyPrint) {
        return (Update) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public Update setQuotaUser(String quotaUser) {
        return (Update) super.setQuotaUser(quotaUser);
      }

      @Override
      public Update setUserIp(String userIp) {
        return (Update) super.setUserIp(userIp);
      }

      /** Project ID of the table to update */
      @com.google.api.client.util.Key
      private String projectId;

      /** Project ID of the table to update
       */
      public String getProjectId() {
        return projectId;
      }

      /** Project ID of the table to update */
      public Update setProjectId(String projectId) {
        this.projectId = projectId;
        return this;
      }

      /** Dataset ID of the table to update */
      @com.google.api.client.util.Key
      private String datasetId;

      /** Dataset ID of the table to update
       */
      public String getDatasetId() {
        return datasetId;
      }

      /** Dataset ID of the table to update */
      public Update setDatasetId(String datasetId) {
        this.datasetId = datasetId;
        return this;
      }

      /** Table ID of the table to update */
      @com.google.api.client.util.Key
      private String tableId;

      /** Table ID of the table to update
       */
      public String getTableId() {
        return tableId;
      }

      /** Table ID of the table to update */
      public Update setTableId(String tableId) {
        this.tableId = tableId;
        return this;
      }

    }

  }

  /**
   * Builder for {@link Bigquery}.
   *
   * <p>
   * Implementation is not thread-safe.
   * </p>
   *
   * @since 1.3.0
   */
  public static final class Builder extends AbstractGoogleJsonClient.Builder {

    /**
     * Returns an instance of a new builder.
     *
     * @param transport HTTP transport
     * @param jsonFactory JSON factory
     * @param httpRequestInitializer HTTP request initializer or {@code null} for none
     * @since 1.7
     */
    public Builder(HttpTransport transport, JsonFactory jsonFactory,
        HttpRequestInitializer httpRequestInitializer) {
      super(
          transport,
          jsonFactory,
          DEFAULT_ROOT_URL,
          DEFAULT_SERVICE_PATH,
          httpRequestInitializer,
          false);
    }

    /** Builds a new instance of {@link Bigquery}. */
    @Override
    public Bigquery build() {
      return new Bigquery(getTransport(),
          getHttpRequestInitializer(),
          getRootUrl(),
          getServicePath(),
          getObjectParser(),
          getGoogleClientRequestInitializer(),
          getApplicationName(),
          getSuppressPatternChecks());
    }

    @Override
    public Builder setRootUrl(String rootUrl) {
      return (Builder) super.setRootUrl(rootUrl);
    }

    @Override
    public Builder setServicePath(String servicePath) {
      return (Builder) super.setServicePath(servicePath);
    }

    @Override
    public Builder setHttpRequestInitializer(HttpRequestInitializer httpRequestInitializer) {
      return (Builder) super.setHttpRequestInitializer(httpRequestInitializer);
    }

    @Override
    public Builder setApplicationName(String applicationName) {
      return (Builder) super.setApplicationName(applicationName);
    }

    @Override
    public Builder setSuppressPatternChecks(boolean suppressPatternChecks) {
      return (Builder) super.setSuppressPatternChecks(suppressPatternChecks);
    }

    /**
     * Set the {@link BigqueryRequestInitializer}.
     *
     * @since 1.12
     */
    public Builder setBigqueryRequestInitializer(
        BigqueryRequestInitializer bigqueryRequestInitializer) {
      return (Builder) super.setGoogleClientRequestInitializer(bigqueryRequestInitializer);
    }

    @Override
    public Builder setGoogleClientRequestInitializer(
        GoogleClientRequestInitializer googleClientRequestInitializer) {
      return (Builder) super.setGoogleClientRequestInitializer(googleClientRequestInitializer);
    }
  }
}
