/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.bigquery.model;

import com.google.api.client.json.GenericJson;

/**
 * Model definition for Job.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the BigQuery API. For a detailed explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class Job extends GenericJson {

  /**
   * [Required] Describes the job configuration.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private JobConfiguration configuration;

  /**
   * [Output-only] A hash of this resource.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String etag;

  /**
   * [Output-only] Opaque ID field of the job
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String id;

  /**
   * [Optional] Reference describing the unique-per-user name of the job.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private JobReference jobReference;

  /**
   * [Output-only] The type of the resource.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String kind;

  /**
   * [Output-only] A URL that can be used to access this resource again.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String selfLink;

  /**
   * [Output-only] Information about the job, including starting time and ending time of the job.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private JobStatistics statistics;

  /**
   * [Output-only] The status of this job. Examine this value when polling an asynchronous job to
   * see if the job is complete.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private JobStatus status;

  /**
   * [Required] Describes the job configuration.
   * The value returned may be {@code null}.
   */
  public JobConfiguration getConfiguration() {
    return configuration;
  }

  /**
   * [Required] Describes the job configuration.
   * The value set may be {@code null}.
   */
  public Job setConfiguration(JobConfiguration configuration) {
    this.configuration = configuration;
    return this;
  }

  /**
   * [Output-only] A hash of this resource.
   * The value returned may be {@code null}.
   */
  public String getEtag() {
    return etag;
  }

  /**
   * [Output-only] A hash of this resource.
   * The value set may be {@code null}.
   */
  public Job setEtag(String etag) {
    this.etag = etag;
    return this;
  }

  /**
   * [Output-only] Opaque ID field of the job
   * The value returned may be {@code null}.
   */
  public String getId() {
    return id;
  }

  /**
   * [Output-only] Opaque ID field of the job
   * The value set may be {@code null}.
   */
  public Job setId(String id) {
    this.id = id;
    return this;
  }

  /**
   * [Optional] Reference describing the unique-per-user name of the job.
   * The value returned may be {@code null}.
   */
  public JobReference getJobReference() {
    return jobReference;
  }

  /**
   * [Optional] Reference describing the unique-per-user name of the job.
   * The value set may be {@code null}.
   */
  public Job setJobReference(JobReference jobReference) {
    this.jobReference = jobReference;
    return this;
  }

  /**
   * [Output-only] The type of the resource.
   * The value returned may be {@code null}.
   */
  public String getKind() {
    return kind;
  }

  /**
   * [Output-only] The type of the resource.
   * The value set may be {@code null}.
   */
  public Job setKind(String kind) {
    this.kind = kind;
    return this;
  }

  /**
   * [Output-only] A URL that can be used to access this resource again.
   * The value returned may be {@code null}.
   */
  public String getSelfLink() {
    return selfLink;
  }

  /**
   * [Output-only] A URL that can be used to access this resource again.
   * The value set may be {@code null}.
   */
  public Job setSelfLink(String selfLink) {
    this.selfLink = selfLink;
    return this;
  }

  /**
   * [Output-only] Information about the job, including starting time and ending time of the job.
   * The value returned may be {@code null}.
   */
  public JobStatistics getStatistics() {
    return statistics;
  }

  /**
   * [Output-only] Information about the job, including starting time and ending time of the job.
   * The value set may be {@code null}.
   */
  public Job setStatistics(JobStatistics statistics) {
    this.statistics = statistics;
    return this;
  }

  /**
   * [Output-only] The status of this job. Examine this value when polling an asynchronous job to
   * see if the job is complete.
   * The value returned may be {@code null}.
   */
  public JobStatus getStatus() {
    return status;
  }

  /**
   * [Output-only] The status of this job. Examine this value when polling an asynchronous job to
   * see if the job is complete.
   * The value set may be {@code null}.
   */
  public Job setStatus(JobStatus status) {
    this.status = status;
    return this;
  }

}
