/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.bigquery.model;

import com.google.api.client.json.GenericJson;

/**
 * Model definition for JobConfigurationLoad.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the BigQuery API. For a detailed explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class JobConfigurationLoad extends GenericJson {

  /**
   * [Optional] Accept rows that are missing trailing optional columns. The missing values are
   * treated as nulls. Default is false which treats short rows as errors. Only applicable to CSV,
   * ignored for other formats.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Boolean allowJaggedRows;

  /**
   * Indicates if BigQuery should allow quoted data sections that contain newline characters in a
   * CSV file. The default value is false.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Boolean allowQuotedNewlines;

  /**
   * [Optional] Specifies whether the job is allowed to create new tables. The following values are
   * supported: CREATE_IF_NEEDED: If the table does not exist, BigQuery creates the table.
   * CREATE_NEVER: The table must already exist. If it does not, a 'notFound' error is returned in
   * the job result. The default value is CREATE_IF_NEEDED. Creation, truncation and append actions
   * occur as one atomic update upon job completion.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String createDisposition;

  /**
   * [Required] The destination table to load the data into.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private TableReference destinationTable;

  /**
   * [Optional] The character encoding of the data. The supported values are UTF-8 or ISO-8859-1.
   * The default value is UTF-8. BigQuery decodes the data after the raw, binary data has been split
   * using the values of the quote and fieldDelimiter properties.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String encoding;

  /**
   * [Optional] The separator for fields in a CSV file. BigQuery converts the string to ISO-8859-1
   * encoding, and then uses the first byte of the encoded string to split the data in its raw,
   * binary state. BigQuery also supports the escape sequence "\t" to specify a tab separator. The
   * default value is a comma (',').
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String fieldDelimiter;

  /**
   * [Optional] The maximum number of bad records that BigQuery can ignore when running the job. If
   * the number of bad records exceeds this value, an 'invalid' error is returned in the job result
   * and the job fails. The default value is 0, which requires that all records are valid.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Integer maxBadRecords;

  /**
   * [Optional] The value that is used to quote data sections in a CSV file. BigQuery converts the
   * string to ISO-8859-1 encoding, and then uses the first byte of the encoded string to split the
   * data in its raw, binary state. The default value is a double-quote ('"'). If your data does not
   * contain quoted sections, set the property value to an empty string. If your data contains
   * quoted newline characters, you must also set the allowQuotedNewlines property to true.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String quote;

  /**
   * [Optional] The schema for the destination table. The schema can be omitted if the destination
   * table already exists or if the schema can be inferred from the loaded data.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private TableSchema schema;

  /**
   * [Deprecated] The inline schema. For CSV schemas, specify as "Field1:Type1[,Field2:Type2]*". For
   * example, "foo:STRING, bar:INTEGER, baz:FLOAT".
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String schemaInline;

  /**
   * [Deprecated] The format of the schemaInline property.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String schemaInlineFormat;

  /**
   * [Optional] The number of rows at the top of a CSV file that BigQuery will skip when loading the
   * data. The default value is 0. This property is useful if you have header rows in the file that
   * should be skipped.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Integer skipLeadingRows;

  /**
   * [Optional] The format of the data files. For CSV files, specify "CSV". For datastore backups,
   * specify "DATASTORE_BACKUP". For newline-delimited JSON, specify "NEWLINE_DELIMITED_JSON". The
   * default value is CSV.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String sourceFormat;

  /**
   * [Required] The fully-qualified URIs that point to your data on Google Cloud Storage.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<String> sourceUris;

  /**
   * [Optional] Specifies the action that occurs if the destination table already exists. Each
   * action is atomic and only occurs if BigQuery is able to fully load the data and the load job
   * completes without error. The following values are supported: WRITE_TRUNCATE: If the table
   * already exists, BigQuery overwrites the table. WRITE_APPEND: If the table already exists,
   * BigQuery appends the data to the table. WRITE_EMPTY: If the table already exists, a 'duplicate'
   * error is returned in the job result. Creation, truncation and append actions occur as one
   * atomic update upon job completion.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String writeDisposition;

  /**
   * [Optional] Accept rows that are missing trailing optional columns. The missing values are
   * treated as nulls. Default is false which treats short rows as errors. Only applicable to CSV,
   * ignored for other formats.
   * The value returned may be {@code null}.
   */
  public Boolean getAllowJaggedRows() {
    return allowJaggedRows;
  }

  /**
   * [Optional] Accept rows that are missing trailing optional columns. The missing values are
   * treated as nulls. Default is false which treats short rows as errors. Only applicable to CSV,
   * ignored for other formats.
   * The value set may be {@code null}.
   */
  public JobConfigurationLoad setAllowJaggedRows(Boolean allowJaggedRows) {
    this.allowJaggedRows = allowJaggedRows;
    return this;
  }

  /**
   * Indicates if BigQuery should allow quoted data sections that contain newline characters in a
   * CSV file. The default value is false.
   * The value returned may be {@code null}.
   */
  public Boolean getAllowQuotedNewlines() {
    return allowQuotedNewlines;
  }

  /**
   * Indicates if BigQuery should allow quoted data sections that contain newline characters in a
   * CSV file. The default value is false.
   * The value set may be {@code null}.
   */
  public JobConfigurationLoad setAllowQuotedNewlines(Boolean allowQuotedNewlines) {
    this.allowQuotedNewlines = allowQuotedNewlines;
    return this;
  }

  /**
   * [Optional] Specifies whether the job is allowed to create new tables. The following values are
   * supported: CREATE_IF_NEEDED: If the table does not exist, BigQuery creates the table.
   * CREATE_NEVER: The table must already exist. If it does not, a 'notFound' error is returned in
   * the job result. The default value is CREATE_IF_NEEDED. Creation, truncation and append actions
   * occur as one atomic update upon job completion.
   * The value returned may be {@code null}.
   */
  public String getCreateDisposition() {
    return createDisposition;
  }

  /**
   * [Optional] Specifies whether the job is allowed to create new tables. The following values are
   * supported: CREATE_IF_NEEDED: If the table does not exist, BigQuery creates the table.
   * CREATE_NEVER: The table must already exist. If it does not, a 'notFound' error is returned in
   * the job result. The default value is CREATE_IF_NEEDED. Creation, truncation and append actions
   * occur as one atomic update upon job completion.
   * The value set may be {@code null}.
   */
  public JobConfigurationLoad setCreateDisposition(String createDisposition) {
    this.createDisposition = createDisposition;
    return this;
  }

  /**
   * [Required] The destination table to load the data into.
   * The value returned may be {@code null}.
   */
  public TableReference getDestinationTable() {
    return destinationTable;
  }

  /**
   * [Required] The destination table to load the data into.
   * The value set may be {@code null}.
   */
  public JobConfigurationLoad setDestinationTable(TableReference destinationTable) {
    this.destinationTable = destinationTable;
    return this;
  }

  /**
   * [Optional] The character encoding of the data. The supported values are UTF-8 or ISO-8859-1.
   * The default value is UTF-8. BigQuery decodes the data after the raw, binary data has been split
   * using the values of the quote and fieldDelimiter properties.
   * The value returned may be {@code null}.
   */
  public String getEncoding() {
    return encoding;
  }

  /**
   * [Optional] The character encoding of the data. The supported values are UTF-8 or ISO-8859-1.
   * The default value is UTF-8. BigQuery decodes the data after the raw, binary data has been split
   * using the values of the quote and fieldDelimiter properties.
   * The value set may be {@code null}.
   */
  public JobConfigurationLoad setEncoding(String encoding) {
    this.encoding = encoding;
    return this;
  }

  /**
   * [Optional] The separator for fields in a CSV file. BigQuery converts the string to ISO-8859-1
   * encoding, and then uses the first byte of the encoded string to split the data in its raw,
   * binary state. BigQuery also supports the escape sequence "\t" to specify a tab separator. The
   * default value is a comma (',').
   * The value returned may be {@code null}.
   */
  public String getFieldDelimiter() {
    return fieldDelimiter;
  }

  /**
   * [Optional] The separator for fields in a CSV file. BigQuery converts the string to ISO-8859-1
   * encoding, and then uses the first byte of the encoded string to split the data in its raw,
   * binary state. BigQuery also supports the escape sequence "\t" to specify a tab separator. The
   * default value is a comma (',').
   * The value set may be {@code null}.
   */
  public JobConfigurationLoad setFieldDelimiter(String fieldDelimiter) {
    this.fieldDelimiter = fieldDelimiter;
    return this;
  }

  /**
   * [Optional] The maximum number of bad records that BigQuery can ignore when running the job. If
   * the number of bad records exceeds this value, an 'invalid' error is returned in the job result
   * and the job fails. The default value is 0, which requires that all records are valid.
   * The value returned may be {@code null}.
   */
  public Integer getMaxBadRecords() {
    return maxBadRecords;
  }

  /**
   * [Optional] The maximum number of bad records that BigQuery can ignore when running the job. If
   * the number of bad records exceeds this value, an 'invalid' error is returned in the job result
   * and the job fails. The default value is 0, which requires that all records are valid.
   * The value set may be {@code null}.
   */
  public JobConfigurationLoad setMaxBadRecords(Integer maxBadRecords) {
    this.maxBadRecords = maxBadRecords;
    return this;
  }

  /**
   * [Optional] The value that is used to quote data sections in a CSV file. BigQuery converts the
   * string to ISO-8859-1 encoding, and then uses the first byte of the encoded string to split the
   * data in its raw, binary state. The default value is a double-quote ('"'). If your data does not
   * contain quoted sections, set the property value to an empty string. If your data contains
   * quoted newline characters, you must also set the allowQuotedNewlines property to true.
   * The value returned may be {@code null}.
   */
  public String getQuote() {
    return quote;
  }

  /**
   * [Optional] The value that is used to quote data sections in a CSV file. BigQuery converts the
   * string to ISO-8859-1 encoding, and then uses the first byte of the encoded string to split the
   * data in its raw, binary state. The default value is a double-quote ('"'). If your data does not
   * contain quoted sections, set the property value to an empty string. If your data contains
   * quoted newline characters, you must also set the allowQuotedNewlines property to true.
   * The value set may be {@code null}.
   */
  public JobConfigurationLoad setQuote(String quote) {
    this.quote = quote;
    return this;
  }

  /**
   * [Optional] The schema for the destination table. The schema can be omitted if the destination
   * table already exists or if the schema can be inferred from the loaded data.
   * The value returned may be {@code null}.
   */
  public TableSchema getSchema() {
    return schema;
  }

  /**
   * [Optional] The schema for the destination table. The schema can be omitted if the destination
   * table already exists or if the schema can be inferred from the loaded data.
   * The value set may be {@code null}.
   */
  public JobConfigurationLoad setSchema(TableSchema schema) {
    this.schema = schema;
    return this;
  }

  /**
   * [Deprecated] The inline schema. For CSV schemas, specify as "Field1:Type1[,Field2:Type2]*". For
   * example, "foo:STRING, bar:INTEGER, baz:FLOAT".
   * The value returned may be {@code null}.
   */
  public String getSchemaInline() {
    return schemaInline;
  }

  /**
   * [Deprecated] The inline schema. For CSV schemas, specify as "Field1:Type1[,Field2:Type2]*". For
   * example, "foo:STRING, bar:INTEGER, baz:FLOAT".
   * The value set may be {@code null}.
   */
  public JobConfigurationLoad setSchemaInline(String schemaInline) {
    this.schemaInline = schemaInline;
    return this;
  }

  /**
   * [Deprecated] The format of the schemaInline property.
   * The value returned may be {@code null}.
   */
  public String getSchemaInlineFormat() {
    return schemaInlineFormat;
  }

  /**
   * [Deprecated] The format of the schemaInline property.
   * The value set may be {@code null}.
   */
  public JobConfigurationLoad setSchemaInlineFormat(String schemaInlineFormat) {
    this.schemaInlineFormat = schemaInlineFormat;
    return this;
  }

  /**
   * [Optional] The number of rows at the top of a CSV file that BigQuery will skip when loading the
   * data. The default value is 0. This property is useful if you have header rows in the file that
   * should be skipped.
   * The value returned may be {@code null}.
   */
  public Integer getSkipLeadingRows() {
    return skipLeadingRows;
  }

  /**
   * [Optional] The number of rows at the top of a CSV file that BigQuery will skip when loading the
   * data. The default value is 0. This property is useful if you have header rows in the file that
   * should be skipped.
   * The value set may be {@code null}.
   */
  public JobConfigurationLoad setSkipLeadingRows(Integer skipLeadingRows) {
    this.skipLeadingRows = skipLeadingRows;
    return this;
  }

  /**
   * [Optional] The format of the data files. For CSV files, specify "CSV". For datastore backups,
   * specify "DATASTORE_BACKUP". For newline-delimited JSON, specify "NEWLINE_DELIMITED_JSON". The
   * default value is CSV.
   * The value returned may be {@code null}.
   */
  public String getSourceFormat() {
    return sourceFormat;
  }

  /**
   * [Optional] The format of the data files. For CSV files, specify "CSV". For datastore backups,
   * specify "DATASTORE_BACKUP". For newline-delimited JSON, specify "NEWLINE_DELIMITED_JSON". The
   * default value is CSV.
   * The value set may be {@code null}.
   */
  public JobConfigurationLoad setSourceFormat(String sourceFormat) {
    this.sourceFormat = sourceFormat;
    return this;
  }

  /**
   * [Required] The fully-qualified URIs that point to your data on Google Cloud Storage.
   * The value returned may be {@code null}.
   */
  public java.util.List<String> getSourceUris() {
    return sourceUris;
  }

  /**
   * [Required] The fully-qualified URIs that point to your data on Google Cloud Storage.
   * The value set may be {@code null}.
   */
  public JobConfigurationLoad setSourceUris(java.util.List<String> sourceUris) {
    this.sourceUris = sourceUris;
    return this;
  }

  /**
   * [Optional] Specifies the action that occurs if the destination table already exists. Each
   * action is atomic and only occurs if BigQuery is able to fully load the data and the load job
   * completes without error. The following values are supported: WRITE_TRUNCATE: If the table
   * already exists, BigQuery overwrites the table. WRITE_APPEND: If the table already exists,
   * BigQuery appends the data to the table. WRITE_EMPTY: If the table already exists, a 'duplicate'
   * error is returned in the job result. Creation, truncation and append actions occur as one
   * atomic update upon job completion.
   * The value returned may be {@code null}.
   */
  public String getWriteDisposition() {
    return writeDisposition;
  }

  /**
   * [Optional] Specifies the action that occurs if the destination table already exists. Each
   * action is atomic and only occurs if BigQuery is able to fully load the data and the load job
   * completes without error. The following values are supported: WRITE_TRUNCATE: If the table
   * already exists, BigQuery overwrites the table. WRITE_APPEND: If the table already exists,
   * BigQuery appends the data to the table. WRITE_EMPTY: If the table already exists, a 'duplicate'
   * error is returned in the job result. Creation, truncation and append actions occur as one
   * atomic update upon job completion.
   * The value set may be {@code null}.
   */
  public JobConfigurationLoad setWriteDisposition(String writeDisposition) {
    this.writeDisposition = writeDisposition;
    return this;
  }

}
