/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.bigquery.model;

import com.google.api.client.json.GenericJson;

/**
 * Model definition for JobConfigurationQuery.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the BigQuery API. For a detailed explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class JobConfigurationQuery extends GenericJson {

  /**
   * [Experimental] If true, allows >128M results to be materialized in the destination table.
   * Requires destination_table to be set.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Boolean allowLargeResults;

  /**
   * [Optional] Whether to create the table if it doesn't already exist (CREATE_IF_NEEDED) or to
   * require the table already exist (CREATE_NEVER). Default is CREATE_IF_NEEDED.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String createDisposition;

  /**
   * [Optional] Specifies the default dataset to assume for unqualified table names in the query.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private DatasetReference defaultDataset;

  /**
   * [Optional] Describes the table where the query results should be stored. If not present, a new
   * table will be created to store the results.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private TableReference destinationTable;

  /**
   * [Experimental] Specifies the the minimum fraction of data that must be scanned before a query
   * returns. This should be specified as a value between 0.0 and 1.0 inclusive. The default value
   * is 1.0.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Double minCompletionRatio;

  /**
   * [Experimental] If set, preserve null values in table data, rather than mapping null values to
   * the column's default value. This flag currently defaults to false, but the default will soon be
   * changed to true. Shortly afterward, this flag will be removed completely. Please specify true
   * if possible, and false only if you need to force the old behavior while updating client code.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Boolean preserveNulls;

  /**
   * [Optional] Specifies a priority for the query. Default is INTERACTIVE. Alternative is BATCH.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String priority;

  /**
   * [Required] BigQuery SQL query to execute.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String query;

  /**
   * [Optional] Whether to look for the result in the query cache. The query cache is a best-effort
   * cache that will be flushed whenever tables in the query are modified. Moreover, the query cache
   * is only available when a query does not have a destination table specified.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Boolean useQueryCache;

  /**
   * [Optional] Whether to overwrite an existing table (WRITE_TRUNCATE), append to an existing table
   * (WRITE_APPEND), or require that the the table is empty (WRITE_EMPTY). Default is WRITE_EMPTY.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String writeDisposition;

  /**
   * [Experimental] If true, allows >128M results to be materialized in the destination table.
   * Requires destination_table to be set.
   * The value returned may be {@code null}.
   */
  public Boolean getAllowLargeResults() {
    return allowLargeResults;
  }

  /**
   * [Experimental] If true, allows >128M results to be materialized in the destination table.
   * Requires destination_table to be set.
   * The value set may be {@code null}.
   */
  public JobConfigurationQuery setAllowLargeResults(Boolean allowLargeResults) {
    this.allowLargeResults = allowLargeResults;
    return this;
  }

  /**
   * [Optional] Whether to create the table if it doesn't already exist (CREATE_IF_NEEDED) or to
   * require the table already exist (CREATE_NEVER). Default is CREATE_IF_NEEDED.
   * The value returned may be {@code null}.
   */
  public String getCreateDisposition() {
    return createDisposition;
  }

  /**
   * [Optional] Whether to create the table if it doesn't already exist (CREATE_IF_NEEDED) or to
   * require the table already exist (CREATE_NEVER). Default is CREATE_IF_NEEDED.
   * The value set may be {@code null}.
   */
  public JobConfigurationQuery setCreateDisposition(String createDisposition) {
    this.createDisposition = createDisposition;
    return this;
  }

  /**
   * [Optional] Specifies the default dataset to assume for unqualified table names in the query.
   * The value returned may be {@code null}.
   */
  public DatasetReference getDefaultDataset() {
    return defaultDataset;
  }

  /**
   * [Optional] Specifies the default dataset to assume for unqualified table names in the query.
   * The value set may be {@code null}.
   */
  public JobConfigurationQuery setDefaultDataset(DatasetReference defaultDataset) {
    this.defaultDataset = defaultDataset;
    return this;
  }

  /**
   * [Optional] Describes the table where the query results should be stored. If not present, a new
   * table will be created to store the results.
   * The value returned may be {@code null}.
   */
  public TableReference getDestinationTable() {
    return destinationTable;
  }

  /**
   * [Optional] Describes the table where the query results should be stored. If not present, a new
   * table will be created to store the results.
   * The value set may be {@code null}.
   */
  public JobConfigurationQuery setDestinationTable(TableReference destinationTable) {
    this.destinationTable = destinationTable;
    return this;
  }

  /**
   * [Experimental] Specifies the the minimum fraction of data that must be scanned before a query
   * returns. This should be specified as a value between 0.0 and 1.0 inclusive. The default value
   * is 1.0.
   * The value returned may be {@code null}.
   */
  public Double getMinCompletionRatio() {
    return minCompletionRatio;
  }

  /**
   * [Experimental] Specifies the the minimum fraction of data that must be scanned before a query
   * returns. This should be specified as a value between 0.0 and 1.0 inclusive. The default value
   * is 1.0.
   * The value set may be {@code null}.
   */
  public JobConfigurationQuery setMinCompletionRatio(Double minCompletionRatio) {
    this.minCompletionRatio = minCompletionRatio;
    return this;
  }

  /**
   * [Experimental] If set, preserve null values in table data, rather than mapping null values to
   * the column's default value. This flag currently defaults to false, but the default will soon be
   * changed to true. Shortly afterward, this flag will be removed completely. Please specify true
   * if possible, and false only if you need to force the old behavior while updating client code.
   * The value returned may be {@code null}.
   */
  public Boolean getPreserveNulls() {
    return preserveNulls;
  }

  /**
   * [Experimental] If set, preserve null values in table data, rather than mapping null values to
   * the column's default value. This flag currently defaults to false, but the default will soon be
   * changed to true. Shortly afterward, this flag will be removed completely. Please specify true
   * if possible, and false only if you need to force the old behavior while updating client code.
   * The value set may be {@code null}.
   */
  public JobConfigurationQuery setPreserveNulls(Boolean preserveNulls) {
    this.preserveNulls = preserveNulls;
    return this;
  }

  /**
   * [Optional] Specifies a priority for the query. Default is INTERACTIVE. Alternative is BATCH.
   * The value returned may be {@code null}.
   */
  public String getPriority() {
    return priority;
  }

  /**
   * [Optional] Specifies a priority for the query. Default is INTERACTIVE. Alternative is BATCH.
   * The value set may be {@code null}.
   */
  public JobConfigurationQuery setPriority(String priority) {
    this.priority = priority;
    return this;
  }

  /**
   * [Required] BigQuery SQL query to execute.
   * The value returned may be {@code null}.
   */
  public String getQuery() {
    return query;
  }

  /**
   * [Required] BigQuery SQL query to execute.
   * The value set may be {@code null}.
   */
  public JobConfigurationQuery setQuery(String query) {
    this.query = query;
    return this;
  }

  /**
   * [Optional] Whether to look for the result in the query cache. The query cache is a best-effort
   * cache that will be flushed whenever tables in the query are modified. Moreover, the query cache
   * is only available when a query does not have a destination table specified.
   * The value returned may be {@code null}.
   */
  public Boolean getUseQueryCache() {
    return useQueryCache;
  }

  /**
   * [Optional] Whether to look for the result in the query cache. The query cache is a best-effort
   * cache that will be flushed whenever tables in the query are modified. Moreover, the query cache
   * is only available when a query does not have a destination table specified.
   * The value set may be {@code null}.
   */
  public JobConfigurationQuery setUseQueryCache(Boolean useQueryCache) {
    this.useQueryCache = useQueryCache;
    return this;
  }

  /**
   * [Optional] Whether to overwrite an existing table (WRITE_TRUNCATE), append to an existing table
   * (WRITE_APPEND), or require that the the table is empty (WRITE_EMPTY). Default is WRITE_EMPTY.
   * The value returned may be {@code null}.
   */
  public String getWriteDisposition() {
    return writeDisposition;
  }

  /**
   * [Optional] Whether to overwrite an existing table (WRITE_TRUNCATE), append to an existing table
   * (WRITE_APPEND), or require that the the table is empty (WRITE_EMPTY). Default is WRITE_EMPTY.
   * The value set may be {@code null}.
   */
  public JobConfigurationQuery setWriteDisposition(String writeDisposition) {
    this.writeDisposition = writeDisposition;
    return this;
  }

}
