/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.bigquery.model;

import com.google.api.client.json.GenericJson;

/**
 * Model definition for JobList.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the BigQuery API. For a detailed explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class JobList extends GenericJson {

  /**
   * A hash of this page of results.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String etag;

  /**
   * List of jobs that were requested.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<Jobs> jobs;

  static {
    // hack to force ProGuard to consider Jobs used, since otherwise it would be stripped out
    // see http://code.google.com/p/google-api-java-client/issues/detail?id=528
    com.google.api.client.util.Data.nullOf(Jobs.class);
  }

  /**
   * The resource type of the response.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String kind;

  /**
   * A token to request the next page of results.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String nextPageToken;

  /**
   * Total number of jobs in this collection.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Integer totalItems;

  /**
   * A hash of this page of results.
   * The value returned may be {@code null}.
   */
  public String getEtag() {
    return etag;
  }

  /**
   * A hash of this page of results.
   * The value set may be {@code null}.
   */
  public JobList setEtag(String etag) {
    this.etag = etag;
    return this;
  }

  /**
   * List of jobs that were requested.
   * The value returned may be {@code null}.
   */
  public java.util.List<Jobs> getJobs() {
    return jobs;
  }

  /**
   * List of jobs that were requested.
   * The value set may be {@code null}.
   */
  public JobList setJobs(java.util.List<Jobs> jobs) {
    this.jobs = jobs;
    return this;
  }

  /**
   * The resource type of the response.
   * The value returned may be {@code null}.
   */
  public String getKind() {
    return kind;
  }

  /**
   * The resource type of the response.
   * The value set may be {@code null}.
   */
  public JobList setKind(String kind) {
    this.kind = kind;
    return this;
  }

  /**
   * A token to request the next page of results.
   * The value returned may be {@code null}.
   */
  public String getNextPageToken() {
    return nextPageToken;
  }

  /**
   * A token to request the next page of results.
   * The value set may be {@code null}.
   */
  public JobList setNextPageToken(String nextPageToken) {
    this.nextPageToken = nextPageToken;
    return this;
  }

  /**
   * Total number of jobs in this collection.
   * The value returned may be {@code null}.
   */
  public Integer getTotalItems() {
    return totalItems;
  }

  /**
   * Total number of jobs in this collection.
   * The value set may be {@code null}.
   */
  public JobList setTotalItems(Integer totalItems) {
    this.totalItems = totalItems;
    return this;
  }

  /**
   * Model definition for JobListJobs.
   */
  public static final class Jobs extends GenericJson {

    /**
     * [Full-projection-only] Specifies the job configuration.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private JobConfiguration configuration;

    /**
     * A result object that will be present only if the job has failed.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private ErrorProto errorResult;

    /**
     * Unique opaque ID of the job.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String id;

    /**
     * Job reference uniquely identifying the job.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private JobReference jobReference;

    /**
     * The resource type.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String kind;

    /**
     * Running state of the job. When the state is DONE, errorResult can be checked to determine
     * whether the job succeeded or failed.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String state;

    /**
     * [Output-only] Information about the job, including starting time and ending time of the job.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private JobStatistics statistics;

    /**
     * [Full-projection-only] Describes the state of the job.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private JobStatus status;

    /**
     * [Full-projection-only] Specifies the job configuration.
     * The value returned may be {@code null}.
     */
    public JobConfiguration getConfiguration() {
      return configuration;
    }

    /**
     * [Full-projection-only] Specifies the job configuration.
     * The value set may be {@code null}.
     */
    public Jobs setConfiguration(JobConfiguration configuration) {
      this.configuration = configuration;
      return this;
    }

    /**
     * A result object that will be present only if the job has failed.
     * The value returned may be {@code null}.
     */
    public ErrorProto getErrorResult() {
      return errorResult;
    }

    /**
     * A result object that will be present only if the job has failed.
     * The value set may be {@code null}.
     */
    public Jobs setErrorResult(ErrorProto errorResult) {
      this.errorResult = errorResult;
      return this;
    }

    /**
     * Unique opaque ID of the job.
     * The value returned may be {@code null}.
     */
    public String getId() {
      return id;
    }

    /**
     * Unique opaque ID of the job.
     * The value set may be {@code null}.
     */
    public Jobs setId(String id) {
      this.id = id;
      return this;
    }

    /**
     * Job reference uniquely identifying the job.
     * The value returned may be {@code null}.
     */
    public JobReference getJobReference() {
      return jobReference;
    }

    /**
     * Job reference uniquely identifying the job.
     * The value set may be {@code null}.
     */
    public Jobs setJobReference(JobReference jobReference) {
      this.jobReference = jobReference;
      return this;
    }

    /**
     * The resource type.
     * The value returned may be {@code null}.
     */
    public String getKind() {
      return kind;
    }

    /**
     * The resource type.
     * The value set may be {@code null}.
     */
    public Jobs setKind(String kind) {
      this.kind = kind;
      return this;
    }

    /**
     * Running state of the job. When the state is DONE, errorResult can be checked to determine
     * whether the job succeeded or failed.
     * The value returned may be {@code null}.
     */
    public String getState() {
      return state;
    }

    /**
     * Running state of the job. When the state is DONE, errorResult can be checked to determine
     * whether the job succeeded or failed.
     * The value set may be {@code null}.
     */
    public Jobs setState(String state) {
      this.state = state;
      return this;
    }

    /**
     * [Output-only] Information about the job, including starting time and ending time of the job.
     * The value returned may be {@code null}.
     */
    public JobStatistics getStatistics() {
      return statistics;
    }

    /**
     * [Output-only] Information about the job, including starting time and ending time of the job.
     * The value set may be {@code null}.
     */
    public Jobs setStatistics(JobStatistics statistics) {
      this.statistics = statistics;
      return this;
    }

    /**
     * [Full-projection-only] Describes the state of the job.
     * The value returned may be {@code null}.
     */
    public JobStatus getStatus() {
      return status;
    }

    /**
     * [Full-projection-only] Describes the state of the job.
     * The value set may be {@code null}.
     */
    public Jobs setStatus(JobStatus status) {
      this.status = status;
      return this;
    }

  }

}
