/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.bigquery.model;

import com.google.api.client.json.GenericJson;

/**
 * Model definition for TableList.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the BigQuery API. For a detailed explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class TableList extends GenericJson {

  /**
   * A hash of this page of results.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String etag;

  /**
   * The type of list.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String kind;

  /**
   * A token to request the next page of results.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String nextPageToken;

  /**
   * Tables in the requested dataset.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<Tables> tables;

  static {
    // hack to force ProGuard to consider Tables used, since otherwise it would be stripped out
    // see http://code.google.com/p/google-api-java-client/issues/detail?id=528
    com.google.api.client.util.Data.nullOf(Tables.class);
  }

  /**
   * The total number of tables in the dataset.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Integer totalItems;

  /**
   * A hash of this page of results.
   * The value returned may be {@code null}.
   */
  public String getEtag() {
    return etag;
  }

  /**
   * A hash of this page of results.
   * The value set may be {@code null}.
   */
  public TableList setEtag(String etag) {
    this.etag = etag;
    return this;
  }

  /**
   * The type of list.
   * The value returned may be {@code null}.
   */
  public String getKind() {
    return kind;
  }

  /**
   * The type of list.
   * The value set may be {@code null}.
   */
  public TableList setKind(String kind) {
    this.kind = kind;
    return this;
  }

  /**
   * A token to request the next page of results.
   * The value returned may be {@code null}.
   */
  public String getNextPageToken() {
    return nextPageToken;
  }

  /**
   * A token to request the next page of results.
   * The value set may be {@code null}.
   */
  public TableList setNextPageToken(String nextPageToken) {
    this.nextPageToken = nextPageToken;
    return this;
  }

  /**
   * Tables in the requested dataset.
   * The value returned may be {@code null}.
   */
  public java.util.List<Tables> getTables() {
    return tables;
  }

  /**
   * Tables in the requested dataset.
   * The value set may be {@code null}.
   */
  public TableList setTables(java.util.List<Tables> tables) {
    this.tables = tables;
    return this;
  }

  /**
   * The total number of tables in the dataset.
   * The value returned may be {@code null}.
   */
  public Integer getTotalItems() {
    return totalItems;
  }

  /**
   * The total number of tables in the dataset.
   * The value set may be {@code null}.
   */
  public TableList setTotalItems(Integer totalItems) {
    this.totalItems = totalItems;
    return this;
  }

  /**
   * Model definition for TableListTables.
   */
  public static final class Tables extends GenericJson {

    /**
     * The user-friendly name for this table.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String friendlyName;

    /**
     * An opaque ID of the table
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String id;

    /**
     * The resource type.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String kind;

    /**
     * A reference uniquely identifying the table.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private TableReference tableReference;

    /**
     * The user-friendly name for this table.
     * The value returned may be {@code null}.
     */
    public String getFriendlyName() {
      return friendlyName;
    }

    /**
     * The user-friendly name for this table.
     * The value set may be {@code null}.
     */
    public Tables setFriendlyName(String friendlyName) {
      this.friendlyName = friendlyName;
      return this;
    }

    /**
     * An opaque ID of the table
     * The value returned may be {@code null}.
     */
    public String getId() {
      return id;
    }

    /**
     * An opaque ID of the table
     * The value set may be {@code null}.
     */
    public Tables setId(String id) {
      this.id = id;
      return this;
    }

    /**
     * The resource type.
     * The value returned may be {@code null}.
     */
    public String getKind() {
      return kind;
    }

    /**
     * The resource type.
     * The value set may be {@code null}.
     */
    public Tables setKind(String kind) {
      this.kind = kind;
      return this;
    }

    /**
     * A reference uniquely identifying the table.
     * The value returned may be {@code null}.
     */
    public TableReference getTableReference() {
      return tableReference;
    }

    /**
     * A reference uniquely identifying the table.
     * The value set may be {@code null}.
     */
    public Tables setTableReference(TableReference tableReference) {
      this.tableReference = tableReference;
      return this;
    }

  }

}
